OC.L10N.register(
    "spreed",
    {
    "a conversation" : "rozmowa",
    "(Duration %s)" : "(Czas trwania %s)",
    "You attended a call with {user1}" : "Brałeś udział w rozmowie z {user1}",
    "_%n guest_::_%n guests_" : ["%n gość","%n gości","%n gości","%n gości"],
    "You attended a call with {user1} and {user2}" : "Brałeś udział w rozmowie z {user1} i {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Brałeś udział w rozmowie z {user1}, {user2} i {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Brałeś udział w rozmowie z {user1}, {user2}, {user3} i {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Brałeś udział w rozmowie z {user1}, {user2}, {user3}, {user4} i {user5}",
    "_%n other_::_%n others_" : ["%n innym","%n innymi","%n innymi","%n innymi"],
    "{actor} invited you to {call}" : "{actor} zaprosił Ciebie do {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Zostałeś zaproszony do <strong>rozmowy</strong> lub miałeś <strong>połączenie</strong>",
    "Other activities" : "Inne aktywności",
    "Talk" : "Talk",
    "Guest" : "Gość",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Witamy w Nextcloud Talk!\nW tej rozmowie zostaniesz poinformowany o nowych funkcjach dostępnych w Nextcloud Talk.",
    "## New in Talk %s" : "## Nowość w Talku %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge i Safari mogą być teraz używane do połączeń audio i wideo",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Rozmowy indywidualne są teraz stałe i nie można ich przypadkowo zmienić na rozmowy grupowe. Również gdy jeden z uczestników opuszcza rozmowę, rozmowa nie jest automatycznie usuwana. Rozmowa zostanie usunięta z serwera tylko wtedy, gdy obaj uczestnicy opuszczą ją.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "* Możesz teraz powiadomić wszystkich uczestników, wysyłając na czacie wiadomość \"@all\"",
    "- With the \"arrow-up\" key you can repost your last message" : "- Za pomocą klawisza \"strzałka w górę\" możesz ponownie umieścić swoją ostatnią wiadomość",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk obsługuje teraz polecenia. Aby sprawdzić, czy administrator skonfigurował je, wyślij \"/help\" jako wiadomość na czacie",
    "- With projects you can create quick links between conversations, files and other items" : "- Dzięki projektom możesz tworzyć szybkie łącza między rozmowami, plikami i innymi elementami",
    "- You can now mention guests in the chat" : "- Możesz teraz wspomnieć o gościach na czacie",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Rozmowy mają teraz poczekalnie. Umożliwia to moderatorom dołączenie do czatu, aby porozmawiać o przygotowaniu spotkania, podczas oczekiwania na nią przez użytkowników i gości",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Możesz teraz bezpośrednio odpowiadać na wiadomości, dając innym użytkownikom szerszy kontekst na temat Twojej wiadomości",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Wyszukiwanie rozmów i uczestników będzie teraz również filtrować istniejące rozmowy, co znacznie ułatwi znajdowanie wcześniejszych rozmów",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Możesz teraz dodawać własne grupy użytkowników do rozmów dzięki zainstalowanej aplikacji kręgów",
    "- Check out the new grid and call view" : "- Sprawdź nowy widok siatki i połączeń",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Możesz teraz przesyłać i przeciągać pliki bezpośrednio z urządzenia do czatu",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Udostępniane pliki są teraz otwierane bezpośrednio w widoku czatu za pomocą aplikacji przeglądarki",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Możesz teraz wyszukiwać czaty i wiadomości w ujednoliconym wyszukiwaniu na górnym pasku",
    "- Spice up your messages with emojis from the emoji picker" : "- Urozmaicaj swoje wiadomości emotikonami z selektora emoji",
    "- You can now change your camera and microphone while being in a call" : "- Możesz teraz zmienić kamerę i mikrofon podczas rozmowy",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Nadaj swoim rozmowom kontekst za pomocą opisu i otwórz go, aby zalogowani użytkownicy mogli go znaleźć i dołączyć do Ciebie",
    "- See a read status and send failed messages again" : "- Zobacz status odczytu i ponownie wyślij nieodczytane wiadomości",
    "- Raise your hand in a call with the R key" : "- Podnieś rękę w rozmowie za pomocą klawisza R.",
    "- Join the same conversation and call from multiple devices" : "- Dołącz do tej samej rozmowy i wykonuj połączenia z wielu urządzeń",
    "- Send voice messages, share your location or contact details" : "- Wysyłaj wiadomości głosowe, udostępniaj swoją lokalizację lub dane kontaktowe",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Dodaj grupy do rozmowy, a nowi członkowie grupy zostaną automatycznie dodani jako uczestnicy",
    "- A preview of your audio and video is shown before joining a call" : "- Podgląd audio i wideo jest wyświetlany przed dołączeniem do połączenia",
    "- You can now blur your background in the newly designed call view" : "- Możesz teraz rozmyć tło w nowo zaprojektowanym widoku połączenia",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderatorzy mogą teraz przydzielać uczestnikom ogólne i indywidualne uprawnienia",
    "- You can now react to chat messages" : "- Możesz teraz reagować na wiadomości na czacie",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Na pasku bocznym możesz teraz znaleźć przegląd najnowszych udostępnionych elementów",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Użyj sondy, aby zebrać opinie innych lub ustalić datę",
    "- Configure an expiration time for chat messages" : "- Skonfiguruj czas wygaśnięcia wiadomości na czacie",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Rozpocznij rozmowy bez powiadamiania innych o dużych rozmowach. Po rozpoczęciu połączenia możesz wysyłać indywidualne powiadomienia o połączeniach.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Wysyłaj wiadomości na czacie bez powiadamiania odbiorców, jeśli nie jest to pilne",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emoje można teraz uzupełniać automatycznie, wpisując \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Połącz różne elementy za pomocą nowego inteligentnego wyboru, wpisując \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Moderatorzy mogą teraz tworzyć pokoje podgrup (wymaga zaplecza o wysokiej wydajności)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Można teraz nagrywać rozmowy (wymaga zaplecza o wysokiej wydajności)",
    "- Conversations can now have an avatar or emoji as icon" : "- Rozmowy mogą teraz mieć awatar lub emoji jako ikonę",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Oprócz rozmytego tła w wideo rozmowach dostępne są teraz wirtualne tła",
    "- Reactions are now available during calls" : "- Reakcje są teraz dostępne podczas połączeń",
    "- Typing indicators show which users are currently typing a message" : "- Wskaźniki pisania pokazują, którzy użytkownicy aktualnie piszą wiadomość",
    "- Groups can now be mentioned in chats" : "- Można teraz wspominać o grupach na czatach",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Nagrania rozmów są automatycznie transkrybowane, jeśli zarejestrowana jest aplikacja dostawcy transkrypcji",
    "- Chat messages can be translated if a translation provider app is registered" : "- Wiadomości czatu można tłumaczyć, jeśli zarejestrowana jest aplikacja dostawcy tłumaczeń",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** może być teraz używany w _chat_ messages",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Dostępne są teraz webhooki umożliwiające wdrażanie botów. Zobacz dokumentację, aby uzyskać więcej informacji https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Ustaw przypomnienie w wiadomości na czacie, aby otrzymać później powiadomienie",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Korzystaj z konwersacji **Notatka dla siebie**, aby robić notatki i udostępniać informacje między swoimi urządzeniami",
    "- Captions allow to send a message with a file at the same time" : "- Tytuły umożliwiają jednoczesne wysłanie wiadomości z plikiem",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Wideo mówiącego jest teraz widoczne podczas udostępniania ekranu, a reakcje w połączeniach są animowane",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Wiadomości mogą teraz być edytowane przez zalogowanych autorów i moderatorów przez 6 godzin",
    "- Unsent message drafts are now saved in your browser" : "- Wersje robocze niewysłanych wiadomości są teraz zapisywane w Twojej przeglądarce",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Rozmowy tekstowe można teraz prowadzić w sposób stowarzyszony z innymi serwerami Talk",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Moderatorzy mogą teraz blokować konta i gości, aby uniemożliwić im ponowne dołączenie do rozmowy",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Nadchodzące połączenia z powiązanych wydarzeń w kalendarzu i zastępstw, gdy jest się poza biurem są teraz wyświetlane w rozmowach",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Połączenia mogą być teraz wykonywane w sposób federacyjny z innymi serwerami Talk (wymaga wysokowydajnego zaplecza)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Przedstawiamy klienta stacjonarnego Nextcloud Talk dla systemów Windows, macOS i Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Podsumowuj nagrania rozmów i nieprzeczytane wiadomości na czatach za pomocą Asystenta Nextcloud",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Usprawnienie spotkań z rozpoznawaniem zaproszonych gości na podstawie ich adresu e-mail, importem list uczestników, szkicami ankiet i pobieraniem list uczestników rozmów",
    "- Archive conversations to stay focused" : "- Archiwizuj rozmowy, aby zachować koncentrację",
    "- Schedule a meeting into your calendar from within a conversation" : "- Zaplanuj spotkanie w kalendarzu z poziomu rozmowy",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Wyszukaj wiadomości z bieżącej rozmowy bezpośrednio na pasku bocznym po prawej stronie",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Zobacz więcej rozmów na pierwszy rzut oka dzięki nowej, kompaktowej liście (można ją włączyć w ustawieniach rozmów)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "– Rozmowy spotkań są teraz synchronizowane z tytułem i opisem z kalendarza i pozostają ukryte w wynikach wyszukiwania aż do momentu zbliżenia się terminu rozpoczęcia.",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "– Oznacz rozmowy jako wrażliwe w ustawieniach powiadomień, aby ukryć treść wiadomości na liście rozmów i w powiadomieniach.",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "– Aby otrzymywać powiadomienia push podczas trybu „Nie przeszkadzać”, oznacz rozmowy jako ważne",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "– Dodaj innych uczestników do połączenia jeden na jeden, aby dynamicznie utworzyć nowe połączenie grupowe",
    "- Use threads to keep your chat and discussions organized" : "- Używaj wątków, aby utrzymać porządek w czatach i dyskusjach",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Transkrypcje na żywo są teraz dostępne podczas rozmowy (wymaga aplikacji ExApp do transkrypcji na żywo i wydajnego backendu)",
    "- Moderators can now pin messages so they are kept at the top" : "- Moderatorzy mogą teraz przypinać wiadomości, aby były wyświetlane na górze",
    "- Schedule a message to send it at a later time" : "- Zaplanuj wysłanie wiadomości na później",
    "- Conversation tags, grouping and sorting to organize the conversation list" : "- Tagi rozmów, grupowanie i sortowanie do organizowania listy rozmów",
    "- Voice-rooms to connect spontaneously" : "- Pokoje głosowe do spontanicznego łączenia się",
    "- Presets for quick conversation configuration during creation" : "- Presety do szybkiej konfiguracji rozmowy podczas tworzenia",
    "- Direct calls from profile menus for calls within other apps" : "- Bezpośrednie połączenia z menu profilu dla połączeń w innych aplikacjach",
    "_All %n participant_::_All %n participants_" : ["Wszyscy %n uczestnik","Wszyscy %n uczestników","Wszyscy %n uczestników","Wszyscy %n uczestników"],
    "Talk updates ✅" : "Aktualizacje Talka ✅",
    "Reaction deleted by author" : "Reakcja usunięta przez autora",
    "{actor} created the conversation" : "{actor} utworzył rozmowę",
    "You created the conversation" : "Utworzyłeś rozmowę",
    "System created the conversation" : "System utworzył rozmowę",
    "An administrator created the conversation" : "Administrator utworzył rozmowę",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} zmienił nazwę rozmowy z \"%1$s\" na \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Zmieniłeś nazwę rozmowy z \"%1$s\" na \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administrator zmienił nazwę rozmowy z \"%1$s\" na \"%2$s\"",
    "{actor} set the description" : "{actor} ustawił opis",
    "You set the description" : "Ustawiłeś opis",
    "An administrator set the description" : "Administrator ustawił opis",
    "{actor} removed the description" : "{actor} usunął opis",
    "You removed the description" : "Usunąłeś opis",
    "An administrator removed the description" : "Administrator usunął opis",
    "You started a silent call" : "Rozpocząłeś cichą rozmowę",
    "Outgoing silent call" : "Wychodzące, ciche połączenie",
    "{actor} started a silent call" : "{actor} rozpoczął cichą rozmowę",
    "Incoming silent call" : "Przychodzące ciche połączenie",
    "You started a call" : "Rozpocząłeś połączenie",
    "Outgoing call" : "Połączenie wychodzące",
    "{actor} started a call" : "{actor} rozpoczął połączenie",
    "Incoming call" : "Przychodzące połączenie",
    "{actor} joined the call" : "{actor} dołączył do rozmowy",
    "You joined the call" : "Dołączyłeś do rozmowy",
    "{actor} left the call" : "{actor} rozłączył się",
    "You left the call" : "Rozłączyłeś się",
    "{actor} unlocked the conversation" : "{actor} odblokował rozmowę",
    "You unlocked the conversation" : "Odblokowałeś rozmowę",
    "An administrator unlocked the conversation" : "Administrator odblokował rozmowę",
    "{actor} locked the conversation" : "{actor} zablokował rozmowę",
    "You locked the conversation" : "Zablokowałeś rozmowę",
    "An administrator locked the conversation" : "Administrator zablokował rozmowę",
    "{actor} limited the conversation to the current participants" : "{actor} ograniczył rozmowę do obecnych uczestników",
    "You limited the conversation to the current participants" : "Ograniczyłeś rozmowę do obecnych uczestników",
    "An administrator limited the conversation to the current participants" : "Administrator ograniczył rozmowę do obecnych uczestników",
    "{actor} opened the conversation to registered users" : "{actor} otworzył rozmowę dla zarejestrowanych użytkowników",
    "You opened the conversation to registered users" : "Otworzyłeś rozmowę dla zarejestrowanych użytkowników",
    "An administrator opened the conversation to registered users" : "Administrator otworzył rozmowę dla zarejestrowanych użytkowników",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} otworzył rozmowę zarejestrowanym użytkownikom i użytkownikom utworzonym za pomocą aplikacji Goście",
    "You opened the conversation to registered users and users created with the Guests app" : "Otworzyłeś rozmowę dla zarejestrowanych użytkowników i użytkowników utworzonych za pomocą aplikacji Goście",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Administrator otworzył rozmowę zarejestrowanym użytkownikom i użytkownikom utworzonym za pomocą aplikacji Goście",
    "The conversation is now open to everyone" : "Rozmowa jest teraz otwarta dla wszystkich",
    "{actor} opened the conversation to everyone" : "{actor} otworzył rozmowę dla wszystkich",
    "You opened the conversation to everyone" : "Otworzyłeś rozmowę dla wszystkich",
    "{actor} restricted the conversation to moderators" : "{actor} ograniczył rozmowę tylko dla moderatorów",
    "You restricted the conversation to moderators" : "Ograniczyłeś rozmowę tylko dla moderatorów",
    "{actor} started breakout rooms" : "{actor} założył pokoje podgrup",
    "You started breakout rooms" : "Założyłeś pokoje podgrup",
    "{actor} stopped breakout rooms" : "{actor} zatrzymał pokoje podgrup",
    "You stopped breakout rooms" : "Zatrzymałeś pokoje podgrup",
    "{actor} allowed guests" : "{actor} pozwolił gościom",
    "You allowed guests" : "Pozwoliłeś gościom",
    "An administrator allowed guests" : "Administrator pozwolił gościom",
    "{actor} disallowed guests" : "{actor} odzrzucił gości",
    "You disallowed guests" : "Odrzuciłeś gości",
    "An administrator disallowed guests" : "Administrator zabronił gościom",
    "{actor} set a password" : "{actor} ustawił hasło",
    "You set a password" : "Ustawiłeś hasło",
    "An administrator set a password" : "Administrator ustawił hasło",
    "{actor} removed the password" : "{actor} usunął hasło",
    "You removed the password" : "Usunąłeś hasło",
    "An administrator removed the password" : "Administrator usunął hasło",
    "{actor} added {user}" : "{actor} dodał {user}",
    "You joined the conversation" : "Dołączyłeś do rozmowy",
    "{actor} joined the conversation" : "{actor} dołączył do rozmowy",
    "You added {user}" : "Dodałeś {user}",
    "{actor} added you" : "{actor} dodał Ciebie",
    "An administrator added you" : "Administrator dodał Ciebie",
    "An administrator added {user}" : "Administrator dodał {user}",
    "You left the conversation" : "Opuściłeś rozmowę",
    "{actor} left the conversation" : "{actor} opuścił rozmowę",
    "{actor} removed {user}" : "{actor} usunął {user}",
    "You removed {user}" : "Usunąłeś {user}",
    "{actor} removed you" : "{actor} usunął Ciebie",
    "An administrator removed you" : "Administrator usunął Ciebie",
    "An administrator removed {user}" : "Administrator usunął {user}",
    "{actor} invited {federated_user}" : "{actor} zaprosił {federated_user}",
    "You invited {federated_user}" : "Zaprosiłeś {federated_user}",
    "You accepted the invitation" : "Przyjąłeś zaproszenie",
    "{actor} invited you" : "{actor} zaprosił Ciebie",
    "An administrator invited you" : "Administrator zaprosił Ciebie",
    "An administrator invited {federated_user}" : "Administrator zaprosił {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} przyjął zaproszenie",
    "{actor} removed {federated_user}" : "{actor} usunął {federated_user}",
    "You removed {federated_user}" : "Usunąłeś {federated_user}",
    "You declined the invitation" : "Odrzuciłeś zaproszenie",
    "An administrator removed {federated_user}" : "Administrator usunął {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} odrzucił zaproszenie",
    "{actor} added group {group}" : "{actor} dodał grupę {group}",
    "You added group {group}" : "Dodałeś grupę {group}",
    "An administrator added group {group}" : "Administrator dodał grupę {group}",
    "{actor} removed group {group}" : "{actor} usunął grupę {group}",
    "You removed group {group}" : "Usunąłeś grupę {group}",
    "An administrator removed group {group}" : "Administrator usunął grupę {group}",
    "{actor} added team {circle}" : "{actor} dodał zespół {circle}",
    "You added team {circle}" : "Dodałeś zespół {circle}",
    "An administrator added team {circle}" : "Administrator dodał zespół {circle}",
    "{actor} removed team {circle}" : "{actor} usunął zespół {circle}",
    "You removed team {circle}" : "Usunąłeś zespół {circle}",
    "An administrator removed team {circle}" : "Administrator usunął zespół {circle}",
    "{actor} added {phone}" : "{actor} dodał {phone}",
    "You added {phone}" : "Dodałeś {phone}",
    "An administrator added {phone}" : "Administrator dodał {phone}",
    "{actor} removed {phone}" : "{actor} usunął {phone}",
    "You removed {phone}" : "Usunąłeś {phone}",
    "An administrator removed {phone}" : "Administrator usunął telefon {phone}",
    "{actor} promoted {user} to moderator" : "{actor} awansował {user} na moderatora",
    "You promoted {user} to moderator" : "Awansowałeś {user} na moderatora",
    "{actor} promoted you to moderator" : "{actor} awansował Ciebie na moderatora",
    "An administrator promoted you to moderator" : "Administrator awansował Ciebie na moderatora",
    "An administrator promoted {user} to moderator" : "Administrator awansował {user} na moderatora",
    "{actor} demoted {user} from moderator" : "{actor} zdegradował {user} z moderatora",
    "You demoted {user} from moderator" : "Zdegradowałeś {user} z moderatora",
    "{actor} demoted you from moderator" : "{actor} zdegradował Ciebie z moderatora",
    "An administrator demoted you from moderator" : "Administrator zdegradował Ciebie z moderatora",
    "An administrator demoted {user} from moderator" : "Administrator zdegradował {user} z moderatora",
    "{actor} shared a file which is no longer available" : "{actor} udostępnił plik, który nie jest już dostępny",
    "You shared a file which is no longer available" : "Udostępniłeś plik, który nie jest już dostępny",
    "File shares are currently not supported in federated conversations" : "Współdzielenie plików nie jest obecnie obsługiwane w konwersacjach federacyjnych",
    "The shared location is malformed" : "Udostępniona lokalizacja jest zniekształcona",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} skonfigurował Matterbridge, aby zsynchronizować tę rozmowę z innymi czatami",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Skonfigurowałeś Matterbridge, aby zsynchronizować tę rozmowę z innymi czatami",
    "{actor} created thread {title}" : "{actor} utworzył wątek {title}",
    "You created thread {title}" : "Utworzyłeś wątek {title}",
    "{actor} renamed thread {title}" : "{actor} zmienił nazwę wątku {title}",
    "You renamed thread {title}" : "Zmieniłeś nazwę wątku {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} zaktualizował konfigurację Matterbridge",
    "You updated the Matterbridge configuration" : "Zaktualizowałeś konfigurację Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} usunął konfigurację Matterbridge",
    "You removed the Matterbridge configuration" : "Usunąłeś konfigurację Matterbridge",
    "{actor} started Matterbridge" : "{actor} uruchomił Matterbridge",
    "You started Matterbridge" : "Uruchomiłeś Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} zatrzymał Matterbridge",
    "You stopped Matterbridge" : "Zatrzymałeś Matterbridge",
    "{actor} deleted a message" : "{actor} usunął wiadomość",
    "You deleted a message" : "Usunąłeś wiadomość",
    "{actor} edited a message" : "{actor} edytował wiadomość",
    "You edited a message" : "Edytowałeś wiadomość",
    "{actor} pinned a message" : "{actor} przypiął wiadomość",
    "You pinned a message" : "Przypiąłeś wiadomość",
    "{actor} unpinned a message" : "{actor} odpiął wiadomość",
    "Message was automatically unpinned" : "Wiadomość została automatycznie odpięta",
    "You unpinned a message" : "Odpiąłeś wiadomość",
    "{actor} deleted a reaction" : "{actor} usunął reakcję",
    "You deleted a reaction" : "Usunąłeś reakcję",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Ustawiasz termin ważności wiadomości na %n tydzień","Ustawiasz termin ważności wiadomości na %n tygodnie","Ustawiasz termin ważności wiadomości na %n tygodni","Ustawiasz termin ważności wiadomości na %n tygodni"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Ustawiasz termin ważności wiadomości na %n dzień","Ustawiasz termin ważności wiadomości na %n dni","Ustawiasz termin ważności wiadomości na %n dni","Ustawiasz termin ważności wiadomości na %n dni"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Ustawiasz termin ważności wiadomości na %n godzinę","Ustawiasz termin ważności wiadomości na %n godziny","Ustawiasz termin ważności wiadomości na %n godzin","Ustawiasz termin ważności wiadomości na %n godzin"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Ustawiasz termin ważności wiadomości na %n minutę","Ustawiasz termin ważności wiadomości na %n minuty","Ustawiasz termin ważności wiadomości na %n minut","Ustawiasz termin ważności wiadomości na %n minut"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} ustawił wygaśnięcie wiadomości na %n tydzień","{actor} ustawił wygaśnięcie wiadomości na %n tygodnie","{actor} ustawił wygaśnięcie wiadomości na %n tygodni","{actor} ustawił wygaśnięcie wiadomości na %n tygodni"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} ustawił wygaśnięcie wiadomości na %n dzień","{actor} ustawił wygaśnięcie wiadomości na %n dni","{actor} ustawił wygaśnięcie wiadomości na %n dni","{actor} ustawił wygaśnięcie wiadomości na %n dni"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} ustawił wygaśnięcie wiadomości na %n godzinę","{actor} ustawił wygaśnięcie wiadomości na %n godziny","{actor} ustawił wygaśnięcie wiadomości na %n godzin","{actor} ustawił wygaśnięcie wiadomości na %n godzin"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} ustawił wygaśnięcie wiadomości na %n minutę","{actor} ustawił wygaśnięcie wiadomości na %n minuty","{actor} ustawił wygaśnięcie wiadomości na %n minut","{actor} ustawił wygaśnięcie wiadomości na %n minut"],
    "{actor} disabled message expiration" : "{actor} wyłączył wygaśnięcie wiadomości",
    "You disabled message expiration" : "Wyłączyłeś wygaśnięcie wiadomości",
    "{actor} cleared the history of the conversation" : "{actor} wyczyścił historię rozmowy",
    "You cleared the history of the conversation" : "Wyczyściłeś historię rozmowy",
    "{actor} set the conversation picture" : "{actor} ustawił obraz rozmowy",
    "You set the conversation picture" : "Ustawiłeś obraz rozmowy",
    "{actor} removed the conversation picture" : "{actor} usunął obraz rozmowy",
    "You removed the conversation picture" : "Usunąłeś obraz rozmowy",
    "{actor} ended the poll {poll}" : "{actor} zakończył sondę {poll}",
    "You ended the poll {poll}" : "Zakończyłeś sondę {poll}",
    "{actor} started the video recording" : "{actor} rozpoczął nagrywanie wideo",
    "You started the video recording" : "Rozpocząłeś nagrywanie wideo",
    "{actor} stopped the video recording" : "{actor} zatrzymał nagrywanie wideo",
    "You stopped the video recording" : "Zatrzymałeś nagrywanie wideo",
    "{actor} started the audio recording" : "{actor} rozpoczął nagrywanie dźwięku",
    "You started the audio recording" : "Rozpocząłeś nagrywanie dźwięku",
    "{actor} stopped the audio recording" : "{actor} zatrzymał nagrywanie dźwięku",
    "You stopped the audio recording" : "Zatrzymałeś nagrywanie dźwięku",
    "The recording failed" : "Nagrywanie nie powiodło się",
    "Someone voted on the poll {poll}" : "Ktoś zagłosował w sondzie {poll}",
    "Message deleted by author" : "Wiadomość usunięta przez autora",
    "Message deleted by {actor}" : "Wiadomość usunięta przez {actor}",
    "Message deleted by you" : "Wiadomość usunięta przez Ciebie",
    "Deleted user" : "Usunięty użytkownik",
    "Unknown number" : "Nieznany numer",
    "Administration" : "Administracja",
    "System" : "System",
    "%s (guest)" : "%s (gość)",
    "Missed call" : "Nieodebrane połączenie",
    "Unanswered call" : "Połączenie bez odpowiedzi",
    "Call ended (Duration {duration})" : "Połączenie zakończone (czas trwania {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Połączenie zostało zakończone, ponieważ osiągnięto maksymalny czas trwania połączenia (Czas trwania {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} zakończył połączenie (Czas trwania {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Połączenie z %n gościem zostało zakończone, ponieważ osiągnięto maksymalny czas trwania połączenia (Czas trwania {duration})","Połączenie z %n gośćmi zostało zakończone, ponieważ osiągnięto maksymalny czas trwania połączenia (Czas trwania {duration})","Połączenie z %n gośćmi zostało zakończone, ponieważ osiągnięto maksymalny czas trwania połączenia (Czas trwania {duration})","Połączenie z %n gośćmi zostało zakończone, ponieważ osiągnięto maksymalny czas trwania połączenia (Czas trwania {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Połączenie z %n gościem zakończone (Czas trwania {duration})","Połączenie z %n gośćmi zakończone (Czas trwania {duration})","Połączenie z %n gośćmi zakończone (Czas trwania {duration})","Połączenie z %n gośćmi zakończone (Czas trwania {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} zakończył połączenie z gościem (Czas trwania {duration})","{actor} zakończył połączenie z gośćmi (Czas trwania {duration})","{actor} zakończył połączenie z gośćmi (Czas trwania {duration})","{actor} zakończył połączenie z gośćmi (Czas trwania {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Połączenie z {user1} zostało zakończone, ponieważ osiągnięto maksymalny czas trwania połączenia (Czas trwania {duration})",
    "Call with {user1} ended (Duration {duration})" : "Połączenie z {user1} zakończone (Czas trwania {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} zakończył połączenie z {user1} (Czas trwania {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Połączenie z {user1} i {user2} zostało zakończone, ponieważ osiągnięto maksymalny czas trwania połączenia (Czas trwania {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Połączenie z {user1} i {user2} zakończone (Czas trwania {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} zakończył połączenie z {user1} i {user2} (Czas trwania {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Połączenie z {user1}, {user2} i {user3} zostało zakończone, ponieważ osiągnięto maksymalny czas trwania połączenia (Czas trwania {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Połączenie z {user1}, {user2} i {user3} zakończone (Czas trwania {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} zakończył połączenie z {user1}, {user2} i {user3} (Czas trwania {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Połączenie z {user1}, {user2}, {user3} i {user4} zostało zakończone, ponieważ osiągnięto maksymalny czas trwania połączenia (Czas trwania {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Połączenie z {user1}, {user2}, {user3} i {user4} zakończone (Czas trwania {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} zakończył połączenie z {user1}, {user2}, {user3} i {user4} (Czas trwania {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Połączenie z {user1}, {user2}, {user3}, {user4} i {user5} zostało zakończone, ponieważ osiągnięto maksymalny czas trwania połączenia (Czas trwania {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Połączenie z {user1}, {user2}, {user3}, {user4} i {user5} zakończone (Czas trwania {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} zakończył połączenie z {user1}, {user2}, {user3}, {user4} i {user5} (Czas trwania {duration})",
    "Message of {user} in {conversation}" : "Wiadomość od {user} w {conversation}",
    "Message of {user}" : "Wiadomość od {user}",
    "Message of a deleted user in {conversation}" : "Wiadomość od usuniętego użytkownika w {conversation}",
    "Talk conversations" : "Rozmowy Talk",
    "Call %s" : "Połącz %s",
    "Chat with %s" : "Czat z %s",
    "An error occurred. Please contact your administrator." : "Wystąpił błąd. Skontaktuj się z administratorem.",
    "App disabled" : "Aplikacja wyłączona",
    "Conversation subfolders are disabled" : "Podfoldery rozmów są wyłączone",
    "Storage quota exceeded" : "Limit przekroczony",
    "Could not prepare conversation folder" : "Nie można przygotować folderu rozmowy",
    "File not found" : "Nie odnaleziono pliku",
    "Path must point to a file" : "Ścieżka musi wskazywać na plik",
    "File is not inside the conversation draft folder for this room" : "Plik nie znajduje się w folderze wersji roboczych rozmowy dla tego pokoju",
    "File is not shared, or shared but not with the user" : "Plik nie jest udostępniony, albo nie jest dostępny dla użytkownika",
    "No account available to delete." : "Brak konta do usunięcia.",
    "Poll" : "Sonda",
    "Password needs to be set" : "Należy ustawić hasło",
    "Uploading the file failed" : "Przesyłanie pliku nie powiodło się",
    "No image file provided" : "Nie wskazano pliku obrazu",
    "File is too big" : "Plik jest za duży",
    "Invalid file provided" : "Wskazano nieprawidłowy plik",
    "Invalid image" : "Nieprawidłowy obraz",
    "Unknown filetype" : "Nieznany typ pliku",
    "Talk mentions" : "Wzmianki w Rozmowach",
    "More conversations" : "Więcej rozmów",
    "Say hi to your friends and colleagues!" : "Przywitaj się z przyjaciółmi i współpracownikami!",
    "No unread mentions" : "Brak nieprzeczytanych wzmianek",
    "Call in progress" : "Trwa połączenie",
    "You were mentioned" : "Wspomniano o Tobie",
    "Write to conversation" : "Napisz w rozmowie",
    "Writes event information into a conversation of your choice" : "Zapisuje informacje o zdarzeniu w wybranej rozmowie",
    "Missing email field in header line" : "Brak pola adresu e-mail w wierszu nagłówka",
    "Following lines are invalid: %s" : "Następujące wiersze są nieprawidłowe: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$szaprosił Cię do rozmowy \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Otrzymujesz zaproszenie do rozmowy \"%s\".",
    "Conversation invitation" : "Zaproszenie do rozmowy",
    "Scheduled time" : "Zaplanowany czas",
    "Description" : "Opis",
    "You can also dial-in via phone with the following details" : "Możesz także połączyć się przez telefon z następującymi detalami",
    "Dial-in information" : "Informacje dotyczące połączeń telefonicznych",
    "Meeting ID" : "ID spotkania",
    "Your PIN" : "Twój kod PIN",
    "Click the button below to join the lobby now." : "Kliknij przycisk poniżej, aby dołączyć do poczekalni.",
    "Click the link below to join the lobby now." : "Kliknij link poniżej, aby dołączyć do poczekalni.",
    "Join lobby for \"%s\"" : "Dołącz do poczekalni dla \"%s\"",
    "Click the button below to join the conversation now." : "Kliknij przycisk poniżej, aby dołączyć do rozmowy.",
    "Click the link below to join the conversation now." : "Kliknij poniższy link, aby dołączyć do rozmowy.",
    "Join \"%s\"" : "Dołącz \"%s\"",
    "Meeting" : "Zebranie",
    "Password request: %s" : "Żądanie hasła: %s",
    "Private conversation" : "Rozmowa prywatna",
    "Deleted user (%s)" : "Usunięty użytkownik (%s)",
    "Failed to upload call recording" : "Nie udało się przesłać nagrania rozmowy",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Serwer nagrywający nie mógł przesłać nagrania rozmowy {call}. Skontaktuj się z administracją.",
    "Share to chat" : "Udostępnij na czacie",
    "Dismiss notification" : "Odrzuć powiadomienie",
    "Call recording now available" : "Nagrywanie rozmów jest już dostępne",
    "The recording for the call in {call} was uploaded to {file}." : "Nagranie rozmowy z {call} zostało przesłane do {file}.",
    "Transcript now available" : "Transkrypcja jest już dostępna",
    "The transcript for the call in {call} was uploaded to {file}." : "Transkrypcja rozmowy w {call} została przesłana do {file}.",
    "Failed to transcript call recording" : "Nie udało się dokonać transkrypcji nagrania rozmowy",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Serwer nie zapisał nagrania w pliku {file} dla połączenia {call}. Skontaktuj się z administracją.",
    "Call summary now available" : "Podsumowanie rozmowy już dostępne",
    "The summary for the call in {call} was uploaded to {file}." : "Podsumowanie rozmowy z {call} zostało przesłane do {file}.",
    "Failed to summarize call recording" : "Nie udało się podsumować nagrywania rozmowy",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Serwer nie mógł podsumować nagrania w {file} dla połączenia z {call}. Skontaktuj się z administracją.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} zaprosił Cię do dołączenia do {roomName} na {remoteServer}",
    "Accept" : "Akceptuj",
    "Decline" : "Odrzuć",
    "{user1} invited you to a federated conversation" : "{user1} zaprosił Cię do rozmowy federacyjnej",
    "Someone reacted" : "Ktoś zareagował",
    "New message" : "Nowa wiadomość",
    "Reminder" : "Przypomnienie",
    "Someone mentioned you" : "Ktoś o Tobie wspomniał",
    "Notification" : "Powiadomienie",
    "Someone reacted in a private conversation" : "Ktoś zareagował w prywatnej rozmowie",
    "You received a message in a private conversation" : "Otrzymałeś wiadomość w prywatnej rozmowie",
    "Reminder in a private conversation" : "Przypomnienie w prywatnej rozmowie",
    "Someone mentioned you in a private conversation" : "Ktoś wspomniał o Tobie w prywatnej rozmowie",
    "Notification in a private conversation" : "Powiadomienie w prywatnej rozmowie",
    "Reminder: You in {call}" : "Przypomnienie: Jesteś w {call}",
    "Reminder: {user} in {call}" : "Przypomnienie: {user} w {call}",
    "Reminder: Deleted user in {call}" : "Przypomnienie: Usunięto użytkownika w {call}",
    "Reminder: {guest} (guest) in {call}" : "Przypomnienie: {guest} (guest) w {call}",
    "Reminder: Guest in {call}" : "Przypomnienie: Gość w {call}",
    "{user} reacted with {reaction}" : "{user} zareagował {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} zareagował {reaction} w rozmowie {call}",
    "Deleted user reacted with {reaction} in {call}" : "Usunięty użytkownik zareagował {reaction} w rozmowie {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (gość) zareagował {reaction} w rozmowie {call}",
    "Guest reacted with {reaction} in {call}" : "Gość zareagował {reaction} w trakcie {call}",
    "{user} in {call}" : "{user} w {call}",
    "Deleted user in {call}" : "Usunięty użytkownik w {call}",
    "{guest} (guest) in {call}" : "{guest} (gość) w {call}",
    "Guest in {call}" : "Gość w {call}",
    "{user} sent you a private message" : "{user} wysłał Ci prywatną wiadomość",
    "{user} sent a message in conversation {call}" : "{user} wysłał wiadomość podczas rozmowy {call}",
    "A deleted user sent a message in conversation {call}" : "Usunięty użytkownik wysłał wiadomość w rozmowie {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (gość) wysłał wiadomość w rozmowie {call}",
    "A guest sent a message in conversation {call}" : "Gość wysłał wiadomość podczas rozmowy {call}",
    "{user} replied to your private message" : "{user} odpowiedział na Twoją prywatną wiadomość",
    "{user} replied to your message in conversation {call}" : "{user} odpowiedział na Twoją wiadomość w rozmowie {call}",
    "A deleted user replied to your message in conversation {call}" : "Usunięty użytkownik odpowiedział na Twoją wiadomość w rozmowie {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (gość) odpowiedział na Twoją wiadomość w rozmowie {call}",
    "A guest replied to your message in conversation {call}" : "Gość odpowiedział na Twoją wiadomość w rozmowie {call}",
    "Reminder: You in private conversation {call}" : "Przypomnienie: Prowadzisz rozmowę prywatną {call}",
    "Reminder: A deleted user in private conversation {call}" : "Przypomnienie: Usunięty użytkownik w rozmowie prywatnej {call}",
    "Reminder: {user} in private conversation" : "Przypomnienie: {user} w rozmowie prywatnej",
    "Reminder: You in conversation {call}" : "Przypomnienie: Jesteś w rozmowie {call}",
    "Reminder: {user} in conversation {call}" : "Przypomnienie: {user} w rozmowie {call}",
    "Reminder: A deleted user in conversation {call}" : "Przypomnienie: Usunięty użytkownik w rozmowie {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Przypomnienie: {guest} (gość) w rozmowie {call}",
    "Reminder: A guest in conversation {call}" : "Przypomnienie: Gość w rozmowie {call}",
    "{user} reacted with {reaction} to your private message" : "{user} odpowiedział {reaction} na Twoją prywatną wiadomość",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} odpowiedział {reaction} na Twoją wiadomość w rozmowie {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Usunięty użytkownik odpowiedział {reaction} na Twoją wiadomość w rozmowie {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (gość) odpowiedział {reaction} na Twoją wiadomość w rozmowie {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Gość odpowiedział {reaction} na Twoją wiadomość w rozmowie {call}",
    "{user} mentioned you in a private conversation" : "{user} wspomniał o Tobie w prywatnej rozmowie",
    "{user} mentioned group {group} in conversation {call}" : "{user} wspomniał o grupie {group} w rozmowie {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} wspomniał o zespole {team} w rozmowie {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} wspomniał o wszystkich w rozmowie {call}",
    "{user} mentioned you in conversation {call}" : "{user} wspomniał o Tobie w rozmowie {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Usunięty użytkownik wspomniał o grupie {group} w rozmowie {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Usunięty użytkownik wspomniał o zespole {team} w rozmowie {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Usunięty użytkownik wspomniał o wszystkich w rozmowie {call}",
    "A deleted user mentioned you in conversation {call}" : "Usunięty użytkownik wspomniał o Tobie w rozmowie {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (gość) wspomniał o grupie {group} w rozmowie {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (gość) wspomniał o zespole {team} w rozmowie {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (gość) wspomniał o wszystkich w rozmowie {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gość) wspomniał o Tobie w rozmowie {call}",
    "A guest mentioned group {group} in conversation {call}" : "Gość wspomniał o grupie {group} w rozmowie {call}",
    "A guest mentioned team {team} in conversation {call}" : "Gość wspomniał o zespole {team} w rozmowie {call}",
    "A guest mentioned everyone in conversation {call}" : "Gość wspomniał o wszystkich w rozmowie {call}",
    "A guest mentioned you in conversation {call}" : "Gość wspomniał o Tobie w rozmowie {call}",
    "View message" : "Wyświetl wiadomość",
    "Dismiss reminder" : "Odrzuć przypomnienie",
    "View chat" : "Wyświetl rozmowę",
    "{user} invited you to a group conversation: {call}" : "{user} zaprosił Ciebie na rozmowę grupową: {call}",
    "Join call" : "Dołącz do połączenia",
    "Answer call" : "Odbierz połączenie",
    "{user} would like to talk with you" : "{user} chciałby z Tobą porozmawiać",
    "Call back" : "Oddzwoń",
    "You missed a call from {user}" : "Przeoczyłeś połączenie od {user}",
    "Accept call" : "Zaakceptuj połączenie",
    "Incoming phone call from {call}" : "Nadchodząca rozmowa telefoniczna od {call}",
    "You missed a phone call from {call}" : "Nieodebrane połączenie telefoniczne od {call}",
    "A group call has started in {call}" : "Połączenie grupowe zostało rozpoczęte w {call}",
    "You missed a group call in {call}" : "Przeoczyłeś połączenie grupowe w {call}",
    "{email} is requesting the password to access {file}" : "{email} prosi o hasło dostępu do {file}",
    "{email} tried to request the password to access {file}" : "{email} próbował poprosić o hasło dostępu do {file}",
    "Someone is requesting the password to access {file}" : "Ktoś prosi o hasło, aby uzyskać dostęp do {file}",
    "Someone tried to request the password to access {file}" : "Ktoś próbował poprosić o hasło dostępu do {file}",
    "Open settings" : "Otwórz ustawienia",
    "Hosted signaling server added" : "Dodano hostowany serwer sygnalizacyjny",
    "The hosted signaling server is now configured and will be used." : "Hostowany serwer sygnalizacyjny jest teraz skonfigurowany i gotowy do użycia.",
    "Hosted signaling server removed" : "Usunięto hostowany serwer sygnalizacyjny",
    "The hosted signaling server was removed and will not be used anymore." : "Hostowany serwer sygnalizacyjny został usunięty i nie będzie już używany.",
    "Hosted signaling server changed" : "Zmieniono hostowany serwer sygnalizacyjny",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Konto hostowanego serwera sygnalizacyjnego zmieniło status z \"{oldstatus}\" na \"{newstatus}\".",
    "pending" : "oczekujące",
    "active" : "aktywne",
    "expired" : "wygasłe",
    "blocked" : "zablokowane",
    "error" : "błąd",
    "The certificate of {host} expires in {days} days" : "Certyfikat {host} wygasa za {days} dni",
    "The certificate of {host} expired" : "Certyfikat {host} wygasł",
    "Contact via Talk" : "Kontakt przez Talk",
    "Open Talk" : "Otwórz Talka",
    "Call via Talk" : "Połącz przez Talk",
    "Default" : "Domyślnie",
    "Send messages, create threads, and start voice and video calls." : "Wysyłaj wiadomości, twórz wątki oraz rozpoczynaj połączenia głosowe i wideo.",
    "Presentation" : "Prezentacja",
    "Restricted conversation for internal presentations." : "Rozmowa ograniczona do prezentacji wewnętrznych.",
    "Voice room" : "Pokój głosowy",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "Dołącz bezpośrednio do rozmowy, idealne do szybkich spotkań lub spontanicznych rozmów.",
    "Webinar" : "Webinarium",
    "Restricted conversation with lobby enabled, ideal for public webinars." : "Rozmowa ograniczona z włączonym lobby, idealna do publicznych webinarów.",
    "Conversations" : "Rozmowy",
    "Messages in current conversation" : "Wiadomości w bieżącej rozmowie",
    "{user}" : "{user}",
    "Messages" : "Wiadomości",
    "{user} in {conversation}" : "{user} w {conversation}",
    "Messages in other conversations" : "Wiadomości w innych rozmowach",
    "One-to-one rooms always need to show the other users avatar" : "Pokoje rozmów indywidualnych zawsze muszą pokazywać awatary innych użytkowników",
    "Invalid emoji character" : "Nieprawidłowy znak emoji",
    "Invalid background color" : "Nieprawidłowy kolor tła",
    "Avatar image is not square" : "Obraz awatara nie jest kwadratowy",
    "Room {number}" : "Pokój {number}",
    "Favorites" : "Ulubione",
    "Other" : "Inne",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Nie można żądać wersji testowej, ponieważ serwer testowy jest nieosiągalny. Spróbuj ponownie później.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Wystąpił problem z uwierzytelnieniem tej instancji. Może nie jest dostępny z zewnątrz, aby zweryfikować jego adres URL.",
    "Something unexpected happened." : "Wydarzyło się coś nieoczekiwanego.",
    "The URL is invalid." : "Adres URL jest nieprawidłowy.",
    "An HTTPS URL is required." : "Adres URL HTTPS jest wymagany.",
    "The email address is invalid." : "Adres e-mail jest nieprawidłowy.",
    "The language is invalid." : "Język jest nieprawidłowy.",
    "The country is invalid." : "Kraj jest nieprawidłowy.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Wystąpił problem z żądaniem o wersję testową. Sprawdź swój dziennik, aby uzyskać dodatkowe informacje.",
    "Too many requests are send from your servers address. Please try again later." : "Zbyt wiele żądań jest wysyłanych z adresu Twojego serwera. Spróbuj ponownie później.",
    "There is already a trial registered for this Nextcloud instance." : "Jest już zarejestrowany okres testowy dla tej instancji Nextcloud.",
    "Something unexpected happened. Please try again later." : "Wydarzyło się coś nieoczekiwanego. Spróbuj ponownie później.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Nie można żądać o wersję testową, ponieważ serwer testowy zadziałał nieprawidłowo. Spróbuj ponownie później.",
    "Trial requested but failed to get account information. Please check back later." : "Próba testowa nie powiodła się. Nie można było uzyskać informacji o koncie. Sprawdź później.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Wystąpił problem z uwierzytelnieniem tego żądania. Może nie jest dostępny z zewnątrz, aby zweryfikować jego adres URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Nie udało się pobrać informacji o koncie, ponieważ serwer testowy zadziałał nieprawidłowo. Sprawdź później.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Wystąpił problem z pobraniem informacji o koncie. Sprawdź swój dziennik, aby uzyskać dodatkowe informacje.",
    "There is no such account registered." : "Nie ma takiego zarejestrowanego konta.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Nie udało się pobrać informacji o koncie, ponieważ serwer testowy jest nieosiągalny. Sprawdź później.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Usunięcie konta hostowanego serwera sygnalizacyjnego nie powiodło się. Sprawdź później.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Nie udało się usunąć konta, ponieważ serwer testowy zadziałał nieprawidłowo. Sprawdź później.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Wystąpił problem z usunięciem konta. Sprawdź swój dziennik, aby uzyskać dodatkowe informacje.",
    "Too many requests are sent from your servers address. Please try again later." : "Z adresu Twojego serwera jest wysyłanych zbyt wiele żądań. Spróbuj ponownie później.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Nie udało się usunąć konta, ponieważ serwer testowy jest nieosiągalny. Sprawdź później.",
    "Note to self" : "Notatka dla siebie",
    "A place for your private notes, thoughts and ideas" : "Miejsce na Twoje prywatne notatki, przemyślenia i pomysły",
    "Transcript is AI generated and may contain mistakes" : "Transkrypcja jest generowana przez sztuczną inteligencję i może zawierać błędy",
    "Summary is AI generated and may contain mistakes" : "Podsumowanie jest generowane przez sztuczną inteligencję i może zawierać błędy",
    "Let's get started!" : "Zaczynajmy!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** to bezpieczna, samodzielnie hostowana platforma komunikacyjna, która bezproblemowo integruje się z ekosystemem Nextcloud.\n\n#### Główne funkcje Nextcloud Talk:\n\n* Czat i wiadomości w prywatnych i grupowych czatach\n* Połączenia głosowe i wideo\n* Udostępnianie plików i integracja z innymi aplikacjami Nextcloud\n* Konfigurowalne ustawienia rozmów, moderacja i kontrola prywatności\n* Internet, komputer i urządzenie mobilne (iOS i Android)\n* Prywatna i bezpieczna komunikacja\n\nDowiedz się więcej w [dokumentacji użytkownika](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Witamy w Nextcloud Talk\n\nNextcloud Talk to prywatna i wydajna aplikacja do przesyłania wiadomości, która integruje się z Nextcloud. Rozmawiaj w prywatnych lub grupowych rozmów, współpracuj przez połączenia głosowe i wideo, organizuj webinaria i wydarzenia, dostosowuj swoje rozmowy i nie tylko.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Formatuj teksty, aby tworzyć bogate wiadomości\n\nW Nextcloud Talk możesz używać składni Markdown do formatowania wiadomości. Na przykład zastosuj formatowanie **bold** lub *italic* lub `highlight texts as code`. Możesz nawet tworzyć tabele i dodawać nagłówki do tekstu.\n\nMusisz poprawić literówkę lub zmienić formatowanie? Edytuj wiadomość, klikając \"Edytuj wiadomość\" w menu wiadomości.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Dodaj załączniki i linki\n\nDołącz pliki z Nextcloud Hub za pomocą przycisku \"+\". Udostępniaj elementy z Plików i różnych aplikacji Nextcloud. Niektóre aplikacje obsługują nawet interaktywne widżety, na przykład aplikacja Tekst.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭Niech rozmowy płyną: wspominaj użytkowników, reaguj na wiadomości i więcej\n\nMożesz wspomnieć wszystkich uczestników rozmowy, używając %s lub oznaczyć konkretne osoby, wpisując \"@\" i wybierając ich imię z listy",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Możesz odpowiadać na wiadomości, przekazywać je do innych czatów i osób lub kopiować treść wiadomości.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Zrób więcej dzięki Smart Picker\n\nPo prostu wpisz \"/\" lub przejdź do menu \"+\", aby otworzyć Smart Picker, w którym możesz dołączać różne treści do swoich wiadomości. Możesz skonfigurować Smart Picker, aby móc dodawać elementy z aplikacji Nextcloud, pliki GIF, lokalizacje na mapie, treści generowane przez AI i wiele więcej.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Zarządzaj ustawieniami rozmów\n\nW menu rozmów możesz uzyskać dostęp do różnych ustawień, aby zarządzać swoimi rozmowami, takich jak:\n* Edycja informacji o rozmowie\n* Zarządzanie powiadomieniami\n* Stosowanie licznych reguł moderacji\n* Konfigurowanie dostępu i bezpieczeństwa\n* Włączanie botów\n* i więcej!",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Zjednoczone Emiraty Arabskie",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua i Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktyda",
    "Argentina" : "Argentyna",
    "American Samoa" : "Samoa Amerykańskie",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Wyspy Alandzkie",
    "Azerbaijan" : "Azerbejdżan",
    "Bosnia and Herzegovina" : "Bośnia i Hercegowina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesz",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bułgaria",
    "Bahrain" : "Bahrajn",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermudy",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bolivia, Plurinational State of" : "Boliwia, Wielonarodowe Państwo",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius i Saba (Holandia Karaibska)",
    "Brazil" : "Brazylia",
    "Bahamas" : "Bahamy",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Wyspa Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Białoruś",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Wyspy Kokosowe (Keelinga)",
    "Congo, the Democratic Republic of the" : "Kongo, Demokratyczna Republika",
    "Central African Republic" : "Republika Środkowoafrykańska",
    "Congo" : "Kongo",
    "Switzerland" : "Szwajcaria",
    "Côte d'Ivoire" : "Wybrzeże Kości Słoniowej",
    "Cook Islands" : "Wyspy Cooka",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Chiny",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Kostaryka",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Wyspa Bożego Narodzenia",
    "Cyprus" : "Cypr",
    "Czechia" : "Czechy",
    "Germany" : "Niemcy",
    "Djibouti" : "Dżibuti",
    "Denmark" : "Dania",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Republika Dominikany",
    "Algeria" : "Algieria",
    "Ecuador" : "Ekwador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipt",
    "Western Sahara" : "Sahara Zachodnia",
    "Eritrea" : "Erytrea",
    "Spain" : "Hiszpania",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fidżi ",
    "Falkland Islands (Malvinas)" : "Falklandy (Malwiny)",
    "Micronesia, Federated States of" : "Mikronezja, Federalne Stany",
    "Faroe Islands" : "Wyspy Owcze",
    "France" : "Francja",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Zjednoczone Królestwo Wielkiej Brytanii i Irlandii Północnej",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzja",
    "French Guiana" : "Gujana Francuska",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Gwinea",
    "Guadeloupe" : "Gwadelupa",
    "Equatorial Guinea" : "Gwinea Równikowa",
    "Greece" : "Grecja",
    "South Georgia and the South Sandwich Islands" : "Georgia Południowa i Sandwich Południowy",
    "Guatemala" : "Gwatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Gwinea Bissau",
    "Guyana" : "Gujana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Wyspy Heard i McDonalda",
    "Honduras" : "Honduras",
    "Croatia" : "Chorwacja",
    "Haiti" : "Haiti",
    "Hungary" : "Węgry",
    "Indonesia" : "Indonezja",
    "Ireland" : "Irlandia",
    "Israel" : "Izrael",
    "Isle of Man" : "Wyspa Man",
    "India" : "Indie",
    "British Indian Ocean Territory" : "Brytyjskie Terytorium Oceanu Indyjskiego",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Iran, Islamska Republika",
    "Iceland" : "Islandia",
    "Italy" : "Włochy",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordania",
    "Japan" : "Japonia",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodża",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komory",
    "Saint Kitts and Nevis" : "Saint Kitts i Nevis",
    "Korea, Democratic People's Republic of" : "Korea, Demokratyczna Republika Ludowa",
    "Korea, Republic of" : "Korea, Republika",
    "Kuwait" : "Kuwejt",
    "Cayman Islands" : "Kajmany",
    "Kazakhstan" : "Kazachstan",
    "Lao People's Democratic Republic" : "Laotańska Republika Ludowo-Demokratyczna",
    "Lebanon" : "Liban",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litwa",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Łotwa",
    "Libya" : "Libia",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova, Republic of" : "Mołdawia, Republika",
    "Montenegro" : "Czarnogóra",
    "Saint Martin (French part)" : "Saint Martin (część francuska)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Wyspy Marshalla",
    "North Macedonia" : "Macedonia Północna",
    "Mali" : "Mali",
    "Myanmar" : "Mjanma",
    "Mongolia" : "Mongolia",
    "Macao" : "Makau",
    "Northern Mariana Islands" : "Mariany Północne",
    "Martinique" : "Martynika",
    "Mauritania" : "Mauretania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Malediwy",
    "Malawi" : "Malawi",
    "Mexico" : "Meksyk",
    "Malaysia" : "Malezja",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nowa Kaledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Wyspa Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Holandia",
    "Norway" : "Norwegia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nowa Zelandia",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Polinezja Francuska",
    "Papua New Guinea" : "Papua Nowa Gwinea",
    "Philippines" : "Filipiny",
    "Pakistan" : "Pakistan",
    "Poland" : "Polska",
    "Saint Pierre and Miquelon" : "Saint Pierre i Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Portoryko",
    "Palestine, State of" : "Palestyna, Stan",
    "Portugal" : "Portugalia",
    "Palau" : "Palau",
    "Paraguay" : "Paragwaj",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rumunia",
    "Serbia" : "Serbia",
    "Russian Federation" : "Rosja",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabia Saudyjska",
    "Solomon Islands" : "Wyspy Solomona",
    "Seychelles" : "Seszele",
    "Sudan" : "Sudan",
    "Sweden" : "Szwecja",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Wyspa Świętej Heleny, Wyspa Wniebowstąpienia i Tristan da Cunha",
    "Slovenia" : "Słowenia",
    "Svalbard and Jan Mayen" : "Svalbard i Jan Mayen",
    "Slovakia" : "Słowacja",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sudan Południowy",
    "Sao Tome and Principe" : "Wyspy Świętego Tomasza i Książęca",
    "El Salvador" : "Salwador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (część holenderska)",
    "Syrian Arab Republic" : "Syria",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Wyspy Turks i Caicos",
    "Chad" : "Czad",
    "French Southern Territories" : "Francuskie Terytoria Południowe",
    "Togo" : "Togo",
    "Thailand" : "Tajlandia",
    "Tajikistan" : "Tadżykistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Wschodni",
    "Turkmenistan" : "Turkmenia",
    "Tunisia" : "Tunezja",
    "Tonga" : "Tonga",
    "Turkey" : "Turcja",
    "Trinidad and Tobago" : "Trynidad i Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Tajwan",
    "Tanzania, United Republic of" : "Tanzania, Zjednoczona Republika",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Dalekie Wyspy Mniejsze Stanów Zjednoczonych",
    "United States of America" : "Stany Zjednoczone",
    "Uruguay" : "Urugwaj",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Stolica Apostolska",
    "Saint Vincent and the Grenadines" : "Saint Vincent i Grenadyny",
    "Venezuela, Bolivarian Republic of" : "Wenezuela, Boliwariańska Republika",
    "Virgin Islands, British" : "Wyspy Dziewicze, Brytyjskie",
    "Virgin Islands, U.S." : "Wyspy Dziewicze, Stany Zjednoczone",
    "Viet Nam" : "Wietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis i Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Majotta",
    "South Africa" : "Republika Południowej Afryki",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Rozmycie tła",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Nie można sprawdzić obsługi ładowania WASM. Sprawdź ręcznie, czy Twój serwer internetowy obsługuje pliki `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Twój serwer internetowy nie jest prawidłowo skonfigurowany do dostarczania plików `.wasm`. Jest to zazwyczaj problem z konfiguracją Nginx. W przypadku rozmycia tła wymaga dostosowania, aby dostarczać także pliki `.wasm`. Porównaj swoją konfigurację Nginx z konfiguracją zalecaną w naszej dokumentacji.",
    "Talk configuration values" : "Wartości konfiguracji Talka",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Wymuszanie czasu trwania połączenia jest obsługiwane tylko przez system cron. Włącz system cron lub usuń konfigurację `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Małe wartości `max_call_duration` (obecnie ustawione na %d) nie są egzekwowalne ze względu na ograniczenia techniczne. Zadanie w tle jest wykonywane tylko co 5 minut, więc używaj na własne ryzyko.",
    "Federation" : "Federacja",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Zdecydowanie zaleca się skonfigurowanie \"memcache.locking\", gdy włączony jest Talk Federacyjny.",
    "High-performance backend" : "Zaplecze o wysokiej wydajności",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Brak skonfigurowanego zaplecza o wysokiej wydajności - Uruchomienie Nextcloud Talk bez zaplecza o wysokiej wydajności jest skalowalne tylko dla bardzo małych połączeń (maks. 2–3 uczestników). Skonfiguruj zaplecze o wysokiej wydajności, aby zapewnić bezproblemową pracę połączeń z wieloma uczestnikami.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Uruchamianie trybu \"conversation_cluster\" zaplecza o wysokiej wydajności jest przestarzałe i nie będzie już obsługiwane w nadchodzącej wersji. Zaplecze o wysokiej wydajności obsługuje obecnie prawdziwe klastrowanie, które powinno być używane zamiast tego.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Definiowanie wielu zapleczy o wysokiej wydajności jest przestarzałe i nie będzie już obsługiwane w nadchodzącej wersji. Zamiast tego należy skonfigurować moduł równoważenia obciążenia razem z klastrowanymi serwerami sygnalizacyjnymi i skonfigurować go w ustawieniach Talk.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Zapisany klucz publiczny dla używanego algorytmu %1$s nie pasuje do zapisanego klucza prywatnego. Uruchom %2$s, aby naprawić problem.",
    "High-performance backend not configured correctly. Run %s for details." : "Backend o wysokiej wydajności nie został poprawnie skonfigurowany. Uruchom %s, aby uzyskać szczegóły.",
    "High-performance backend not configured correctly" : "Zaplecze o wysokiej wydajności nie zostało poprawnie skonfigurowane",
    "Error: Cannot connect to server" : "Błąd: Nie można połączyć się z serwerem",
    "Error: Server did not respond with proper JSON" : "Błąd: Serwer nie odpowiedział poprawnie JSON",
    "Error: Certificate expired" : "Błąd: Certyfikat wygasł",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Błąd: Czasy systemowe serwera Nextcloud i serwera zaplecza o wysokiej wydajności są niezsynchronizowane. Upewnij się, że oba serwery są połączone z serwerem czasu lub ręcznie zsynchronizuj ich czas.",
    "Could not get version" : "Nie udało się pobrać wersji",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Błąd: Wersja uruchomiona: {version}; Serwer wymaga aktualizacji, aby był kompatybilny z tą wersją Talk",
    "Error: Server responded with: {error}" : "Błąd: Serwer odpowiedział: {error}",
    "Error: Unknown error occurred" : "Błąd: Wystąpił nieznany błąd",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Ostrzeżenie: Działająca wersja: {version}; Serwer nie obsługuje wszystkich funkcji tej wersji Talka, brakuje funkcji: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Zdecydowanie zaleca się skonfigurowanie pamięci podręcznej w przypadku uruchamiania Nextcloud Talk z zapleczem o wysokiej wydajności.",
    "Client Push" : "Client Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Client Push jest zainstalowany, to poprawia terminowość powiadomień Talk.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} nie jest zainstalowany. Może to powodować opóźnienia powiadomień Talk.",
    "Recording backend" : "Zaplecze nagrywania",
    "Using the recording backend requires a High-performance backend." : "Korzystanie z zaplecza nagrywania wymaga zaplecza o wysokiej wydajności.",
    "No recording backend configured" : "Brak skonfigurowanego zaplecza nagrywania",
    "SIP configuration" : "Konfiguracja SIP",
    "Using the SIP functionality requires a High-performance backend." : "Korzystanie z funkcji SIP wymaga zaplecza o wysokiej wydajności.",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "Przypisane numery telefonów Talk nie mogą zaczynać się od + ani 0. Usuń lub zaktualizuj następujące numery:\n{list}",
    "No SIP backend configured" : "Brak skonfigurowanego zaplecza SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Nieprawidłowa data, format daty musi być RRRR-MM-DD",
    "Conversation not found" : "Nie znaleziono rozmowy",
    "Path is already shared with this conversation" : "Ścieżka jest już udostępniona w tej rozmowie",
    "Chat, video & audio-conferencing using WebRTC" : "Czat, wideo i konferencje audio za pomocą WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Czat, wideokonferencje i audiokonferencje z użyciem WebRTC\n\n* 💬 **Czat** Nextcloud Talk oferuje prosty czat tekstowy, umożliwiający udostępnianie lub przesyłanie plików z aplikacji Pliki Nextcloud lub lokalnego urządzenia oraz wspominanie innych uczestników.\n\n* 👥 **Prywatne, grupowe, publiczne i chronione hasłem połączenia!** Zaproś kogoś, całą grupę lub wyślij publiczny link, aby zaprosić do połączenia.\n\n* 🌐 **Federacyjne czaty** Czatuj z innymi użytkownikami Nextcloud na ich serwerach\n* 💻 **Udostępnianie ekranu!** Udostępnij swój ekran uczestnikom połączenia.\n\n* 🚀 **Integracja z innymi aplikacjami Nextcloud**, takimi jak Pliki, Kalendarz, Status użytkownika, Pulpit nawigacyjny, Przepływ, Mapy, Inteligentny selektor, Kontakty, Tablica i wiele innych.\n* 🌉 **Synchronizacja z innymi rozwiązaniami do czatów** Dzięki integracji [Matterbridge](https://github.com/42wim/matterbridge/) z Talk możesz łatwo zsynchronizować wiele innych rozwiązań do czatów z Talk Nextcloud i odwrotnie.",
    "Leave call" : "Rozłącz się",
    "Navigating away from the page will leave the call in {conversation}" : "Zamknięcie strony spowoduje opuszczenie połączenia w {conversation}",
    "Stay in call" : "Pozostań w połączeniu",
    "Error occurred when getting the conversation information" : "Wystąpił błąd podczas pobierania informacji o konwersacji.",
    "Duplicate session" : "Duplikat sesji",
    "Discuss this file" : "Omów ten plik",
    "Loading …" : "Wczytywanie…",
    "Share this file with others to discuss it" : "Udostępnij ten plik innym osobom, aby go omówić",
    "Join conversation" : "Dołącz do rozmowy",
    "Share this file" : "Udostępnij ten plik",
    "Error occurred when joining the conversation" : "Wystąpił błąd podczas dołączania do rozmowy",
    "Open in full application" : "Otwórz w pełnej aplikacji",
    "This conversation is password-protected." : "Ta rozmowa jest chroniona hasłem.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Wykryliśmy wiele nieprawidłowych prób podania hasła z Twojego adresu IP. Dlatego Twoja następna próba będzie blokowana do 30 sekund.",
    "The password is wrong. Try again." : "Błędne hasło. Spróbuj ponownie.",
    "Password" : "Hasło",
    "Submit" : "Wyślij",
    "Error requesting the password." : "Błąd podczas żądania hasła.",
    "Request password" : "Żądanie hasła",
    "This conversation has ended" : "Rozmowa została zakończona",
    "Close Talk sidebar" : "Zamknij pasek boczny Talka",
    "Open Talk sidebar" : "Otwórz pasek boczny Talka",
    "Everyone" : "Wszyscy",
    "Users and moderators" : "Użytkownicy i moderatorzy",
    "Moderators only" : "Tylko moderatorzy",
    "Disable calls" : "Wyłącz połączenia",
    "Save changes" : "Zapisz zmiany",
    "Saving …" : "Zapisywanie…",
    "Saved!" : "Zapisano!",
    "Limit to groups" : "Ogranicz dla grup",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Gdy wybrana jest co najmniej jedna grupa, to tylko osoby z wymienionej grupy mogą brać udział w rozmowie.",
    "Guests can still join public conversations." : "Goście nadal mogą brać udział w publicznych rozmowach.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Użytkownicy, którzy nie korzystają już z Talka, będą nadal wyświetlani jako uczestnicy poprzednich rozmów wraz z ich wiadomościami, które będą przechowywane w danej rozmowie.",
    "Limit using Talk" : "Ogranicz używanie Talka",
    "Limit creating a public and group conversation" : "Ogranicz tworzenie rozmowy publicznej i grupowej",
    "Limit creating conversations" : "Ogranicz tworzenie rozmów",
    "Limit starting a call" : "Ogranicz rozpoczynanie połączenia",
    "Limit starting calls" : "Ogranicz rozpoczynanie połączeń",
    "When a call has started, everyone with access to the conversation can join the call." : "Wszyscy mający dostęp do rozmowy mogą również dołączyć do połączenia po jego rozpoczęciu.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Na tym serwerze zainstalowane są następujące boty. W dokumentacji znajdziesz szczegółowe informacje na temat {linkstart1}budowania własnego bota{linkend} lub {linkstart2}listę botów{linkend}, które możesz włączyć na swoim serwerze.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Na tym serwerze nie są zainstalowane żadne boty. W dokumentacji znajdziesz szczegółowe informacje na temat {linkstart1}budowania własnego bota{linkend} lub {linkstart2}listę botów{linkend}, które możesz włączyć na swoim serwerze.",
    "Description is not provided" : "Opis nie jest podany",
    "Locked for moderators" : "Zablokowane dla moderatorów",
    "Enabled" : "Włączone",
    "Disabled" : "Wyłączone",
    "Bots settings" : "Ustawienia botów",
    "State" : "Stan",
    "Name" : "Nazwa",
    "Last error" : "Ostatni błąd",
    "Total errors count" : "Całkowita liczba błędów",
    "Find more bots" : "Znajdź więcej botów",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Zaufane serwery można skonfigurować na stronie {linkstart}Ustawienia udostępniania{linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Federacyjne czaty i połączenia działają już. Obsługa załączników pojawi się w przyszłej wersji.",
    "Enable Federation in Talk app" : "Włącz Federację w programie Talk",
    "Permissions" : "Uprawnienia",
    "Allow users to be invited to federated conversations" : "Zezwalaj użytkownikom na zapraszanie ich do rozmów federacyjnych",
    "Allow users to invite federated users into conversation" : "Zezwalaj użytkownikom na zapraszanie użytkowników federacyjnych do rozmów",
    "Only allow to federate with trusted servers" : "Zezwalaj na federację tylko z zaufanymi serwerami",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Gdy zostanie wybrana co najmniej jedna grupa, jedynie osoby z wymienionych grup będą mogły zapraszać użytkowników federacyjnych do rozmów.",
    "Groups allowed to invite federated users" : "Grupy, którym wolno zapraszać użytkowników federacyjnych",
    "Select groups …" : "Wybierz grupy…",
    "All messages" : "Wszystkie wiadomości",
    "@-mentions only" : "Tylko, gdy @-wspomniano",
    "Off" : "Wyłączone",
    "General settings" : "Ustawienia główne",
    "Default notification settings" : "Domyślne ustawienia powiadomienia",
    "Default group notification" : "Domyślne powiadomienie grupy",
    "Default group notification for new groups" : "Domyślne powiadomienie grupy dla nowych grup",
    "Integration into other apps" : "Integracja z innymi aplikacjami",
    "Allow conversations on files" : "Zezwalaj na rozmowy przy plikach",
    "Allow conversations on public shares for files" : "Zezwalaj na rozmowy przy plikach udostępnionych publicznie",
    "End-to-end encrypted calls" : "Szyfrowane połączenia End-to-End",
    "Enable encryption" : "Włącz szyfrowanie",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Połączenia szyfrowane typu End-to-End ze skonfigurowanym mostem SIP wymagają nowszej wersji bardziej wydajnego zaplecza i mostu SIP.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Klienci mobilni nie obsługują obecnie połączeń szyfrowanych metodą End-to-End.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Klikając powyższy przycisk, informacje zawarte w formularzu zostaną wysłane na serwery Struktur AG. Więcej informacji można znaleźć na stronie {linkstart}spreed.eu{linkend}.",
    "Pending" : "Oczekuje",
    "Error" : "Błąd",
    "Blocked" : "Zablokowani",
    "Active" : "Aktywne",
    "Expired" : "Wygasł",
    "Never" : "Nigdy",
    "The trial could not be requested. Please try again later." : "Nie można zażądać testu. Spróbuj ponownie później.",
    "The account could not be deleted. Please try again later." : "Nie można usunąć konta. Spróbuj ponownie później.",
    "Hosted High-performance backend" : "Hostowane zaplecze o wysokiej wydajności",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Nasz partner Struktur AG zapewnia usługę, na której można zamówić hostowany serwer sygnalizacyjny. W tym celu wystarczy jedynie wypełnić poniższy formularz, a Twoja usługa Nextcloud zrobi to za Ciebie. Po skonfigurowaniu serwera dane uwierzytelniające zostaną wypełnione automatycznie. Spowoduje to zastąpienie istniejących ustawień serwera sygnalizacyjnego.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Jeśli Twoje konto wydajnego backendu zawiera funkcje STUN i/lub TURN, ustawienia zostaną odpowiednio zaktualizowane.",
    "URL of this Nextcloud instance" : "Adres URL tej instancji Nextcloud",
    "Full name of the user requesting the trial" : "Pełna nazwa użytkownika proszącego o test",
    "Email of the user" : "E-mail użytkownika",
    "Language" : "Język",
    "Country" : "Kraj",
    "Request signaling server trial" : "Poproś o próbny serwer sygnalizacyjny",
    "You can see the current status of your hosted signaling server in the following table." : "Aktualny stan hostowanego serwera sygnalizacyjnego można zobaczyć w poniższej tabeli.",
    "Status" : "Status",
    "Created at" : "Utworzono",
    "Expires at" : "Wygasa o",
    "Limits" : "Limity",
    "STUN included" : "STUN włączony",
    "Yes" : "Tak",
    "No" : "Nie",
    "TURN included" : "TURN włączony",
    "Delete the signaling server account" : "Usuń konto serwera sygnalizacyjnego",
    "_%n user_::_%n users_" : ["%n użytkownik","%n użytkowników","%n użytkowników","%n użytkowników"],
    "Installed version: {version}" : "Zainstalowana wersja: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Możesz zainstalować Matterbridge, aby połączyć Nextcloud Talk z innymi usługami. Odwiedź {linkstart1}stronę GitHub{linkend}, aby uzyskać więcej informacji. Pobieranie i instalowanie aplikacji może chwilę potrwać. W przypadku przekroczenia limitu czasu, zainstaluj ją ręcznie z {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Plik binarny Matterbridge ma nieprawidłowe uprawnienia. Upewnij się, że plik binarny Matterbridge jest własnością właściwego użytkownika i ma ustawione prawo do wykonania. Znajdziesz go w „/…/nextcloud/apps/talk_matterbridge/bin/”",
    "Matterbridge binary was not found or couldn't be executed." : "Nie znaleziono pliku binarnego Matterbridge lub nie można go uruchomić.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Możesz również ustawić ścieżkę do pliku binarnego Matterbridge ręcznie za pomocą pliku config. Więcej informacji znajdziesz w {linkstart}dokumentacji integracji Matterbridge{linkend}.",
    "Downloading …" : "Pobieranie…",
    "Install Talk Matterbridge" : "Zainstaluj Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Wystąpił błąd podczas instalacji aplikacji Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Wystąpił błąd podczas instalacji Talk Matterbridge. Zainstaluj ręcznie.",
    "Failed to execute Matterbridge binary." : "Nie udało się uruchomić pliku binarnego Matterbridge.",
    "Matterbridge integration" : "Integracja z Matterbridge",
    "Enable Matterbridge integration" : "Włącz integrację Matterbridge",
    "Status: Checking connection" : "Status: Sprawdzanie połączenia",
    "OK: Running version: {version}" : "W porządku: Uruchomiona wersja: {version}",
    "Error: Server seems to be a Signaling server" : "Błąd: Serwer wydaje się być serwerem sygnalizacyjnym",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Błąd: Czasy systemowe serwera Nextcloud i serwera zaplecza \"Nagrywanie\" są niezsynchronizowane. Upewnij się, że oba serwery są połączone z serwerem czasu lub ręcznie zsynchronizuj ich czas.",
    "Recording backend URL" : "Rejestrowanie adresu URL zaplecza",
    "Validate SSL certificate" : "Potwierdź certyfikat SSL",
    "Delete this server" : "Usuń ten serwer",
    "Test this server" : "Przetestuj ten serwer",
    "Disabled for all calls" : "Wyłączone dla wszystkich połączeń",
    "Enabled for all calls" : "Włączone dla wszystkich połączeń",
    "Configurable on conversation level by moderators" : "Konfigurowalne na poziomie konwersacji przez moderatorów",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Ustawienia PHP \"upload_max_filesize\" lub \"post_max_size\" pozwalają na wysyłanie plików tylko do rozmiaru {maxUpload}.",
    "Recording backend settings saved" : "Zapisano ustawienia zaplecza nagrywania",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Moderatorzy będą mogli włączyć zgodę na poziomie rozmowy. Zgoda na nagrywanie będzie wymagana od każdego uczestnika przed dołączeniem do każdego połączenia w tej rozmowie.",
    "The consent to be recorded will be required for each participant before joining every call." : "Przed przystąpieniem do każdej rozmowy wymagana będzie zgoda na nagrywanie każdego uczestnika.",
    "The consent to be recorded is not required." : "Zgoda na nagrywanie nie jest wymagana.",
    "Recording backend configuration is only possible with a High-performance backend." : "Konfiguracja zaplecza \"Nagrywanie\" jest możliwe tylko przy użyciu zaplecza o wysokiej wydajności.",
    "Add a new recording backend server" : "Dodaj nowy serwer zaplecza nagrywania",
    "Shared secret" : "Klucz współdzielony",
    "Recording consent" : "Zgoda na nagrywanie",
    "Recording transcription" : "Transkrypcja nagrań",
    "Automatically transcribe call recordings with a transcription provider" : "Automatyczne transkrybowanie nagrań rozmów za pomocą dostawcy usług transkrypcji",
    "Automatically summarize call recordings with transcription and summary providers" : "Automatyczne podsumowywanie nagrań rozmów za pomocą dostawców transkrypcji i podsumowań",
    "SIP configuration saved!" : "Konfiguracja SIP zapisana!",
    "SIP configuration is only possible with a High-performance backend." : "Konfiguracja SIP jest możliwa wyłącznie przy użyciu wydajnego zaplecza.",
    "Enable SIP Dial-out option" : "Włącz opcję wybierania numeru SIP",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Serwer sygnalizacyjny musi zostać zaktualizowany do obsługiwanej funkcji wybierania numeru SIP.",
    "Do not show SIP Dial-out caller number" : "Nie pokazuj numeru dzwoniącego SIP Dial-out",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Anonimowy numer powinien być wyświetlany jako „nieznany” lub „ukryty numer” dla odbiorcy połączenia ukryty numer",
    "Dial-out number" : "Numer Dial-out",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Numer w formacie E164 używany jako zapasowy numer dzwoniącego dla połączeń wychodzących",
    "Dial-out prefix" : "Prefiks Dial-out",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Prefiks do skonfigurowanego numeru użytkownika dla połączeń wychodzących (domyślnie „+”)",
    "Restrict SIP configuration" : "Ogranicz konfigurację SIP",
    "Enable SIP configuration" : "Włącz konfigurację SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Tylko użytkownicy z następujących grup mogą włączać SIP w rozmowach, które moderują",
    "Phone number (Country)" : "Numer telefonu (kraj)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Informacje te są wysyłane w wiadomościach e-maili z zaproszeniami, a także wyświetlane na pasku bocznym wszystkim uczestnikom.",
    "Nextcloud base URL" : "Podstawowy adres URL Nextcloud",
    "Talk Backend URL" : "Adres URL zaplecza Talk",
    "WebSocket URL" : "Adres URL WebSocket",
    "Available features" : "Dostępne funkcje",
    "Error: Websocket connection failed" : "Błąd: Połączenie WebSocket nie powiodło się",
    "Error code" : "Kod błędu",
    "Error message" : "Komunikat o błędzie",
    "Error: Websocket connection failed. Check browser console" : "Błąd: Połączenie Websocket nie powiodło się. Sprawdź konsolę przeglądarki",
    "High-performance backend URL" : "Adres URL zaplecza o wysokiej wydajności",
    "Missing High-performance backend warning hidden" : "Ukryte ostrzeżenie zaplecza o wysokiej wydajności",
    "High-performance backend settings saved" : "Zapisano ustawienia zaplecza o wysokiej wydajności",
    "Nextcloud Talk setup not complete" : "Konfiguracja Nextcloud Talk nie została ukończona",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Należy pamiętać, że w przypadku połączeń z więcej niż 2-oma uczestnikami bez zaawansowanego zaplecza, uczestnicy najprawdopodobniej napotkają problemy z łącznością, co spowoduje duże obciążenie urządzeń.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Zainstaluj wydajne zaplecze, aby mieć pewność, że połączenia z wieloma uczestnikami będą przebiegać bezproblemowo.",
    "Nextcloud portal" : "Portal Nextcloud",
    "Quick installation guide" : "Krótki przewodnik instalacji",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Wydajne zaplecze jest wymagane do połączeń i rozmów z wieloma uczestnikami. Bez zaplecza wszyscy uczestnicy muszą wysyłać własne wideo indywidualnie do każdego uczestnika, co najprawdopodobniej spowoduje problemy z łącznością i duże obciążenie urządzeń uczestniczących.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Zdecydowanie zaleca się skonfigurowanie rozproszonej pamięci podręcznej w przypadku korzystania z Nextcloud Talk z zapleczem o wysokiej wydajności.",
    "Add High-performance backend server" : "Dodaj wydajny serwer zaplecza",
    "Warn about connectivity issues in calls with more than 2 participants" : "Ostrzegaj o problemach z łącznością podczas rozmów z udziałem więcej niż z 2-oma uczestnikami",
    "STUN server URL" : "Adres URL serwera STUN",
    "The server address is invalid" : "Adres serwera jest nieprawidłowy",
    "STUN settings saved" : "Zapisano ustawienia STUN",
    "STUN servers" : "Serwery STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Serwer STUN służy do określenia publicznego adresu IP uczestników znajdujących się za routerem.",
    "Add a new STUN server" : "Dodaj nowy serwer STUN",
    "{schema} scheme must be used with a domain" : "Schemat {schema} musi być używany z domeną",
    "{option1} and {option2}" : "{option1} i {option2}",
    "{option} only" : "tylko {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "W porządku: Pomyślnie zwróceni kandydaci ICE przez serwer TURN",
    "Error: No working ICE candidates returned by the TURN server" : "Błąd: Nie działa zwrot kandydatów ICE przez serwer TURN",
    "Testing whether the TURN server returns ICE candidates" : "Testowanie, czy serwer TURN zwraca kandydatów ICE",
    "TURN server schemes" : "Schematy serwerów TURN",
    "TURN server URL" : "Adres URL serwera TURN",
    "TURN server secret" : "Poufny serwer TURN",
    "TURN server protocols" : "Protokoły serwera TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Serwer TURN używany jest do połączeń przez proxy dla uczestników za zaporą. Jeśli poszczególni uczestnicy nie mogą połączyć się z innymi, najprawdopodobniej wymagany jest serwer TURN. Instrukcje instalacji znajdują się w {linkstart}dokumentacji{linkend}.",
    "TURN settings saved" : "Zapisano ustawienia TURN",
    "TURN servers" : "Serwery TURN",
    "Add a new TURN server" : "Dodaj nowy serwer TURN",
    "Failed" : "Nie powiodło się",
    "OK" : "OK",
    "Checking …" : "Sprawdzanie ...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Niepowodzenie: WebAssembly jest wyłączony lub nie jest obsługiwany w tej przeglądarce. Włącz WebAssembly lub użyj przeglądarki z obsługą, aby sprawdzić.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Niepowodzenie: Pliki \".wasm\" i \".tflite\" nie zostały poprawnie zwrócone przez serwer sieciowy. Sprawdź sekcję \"Wymagania systemowe\" w dokumentacji Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: Pliki \".wasm\" i \".tflite\" zostały poprawnie zwrócone przez serwer WWW.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Wygląda na to, że konfiguracja PHP i Apache nie jest kompatybilna. Należy pamiętać, że PHP może być używane tylko z modułem MPM_PREFORK, a PHP-FPM może być używane tylko z modułem MPM_EVENT.",
    "Web server setup checks" : "Sprawdzanie konfiguracji serwera WWW",
    "Files required for virtual background can be loaded" : "Można załadować pliki potrzebne do wirtualnego tła",
    "Federated user" : "Użytkownik sfederowany",
    "Assign participants to rooms" : "Przypisz uczestników do pokoi",
    "Configure breakout rooms" : "Skonfiguruj pokoje podgrup",
    "Number of breakout rooms" : "Liczba pokoi podgrup",
    "You can create from 1 to 20 breakout rooms." : "Możesz utworzyć od 1 do 20 pokoi podgrup.",
    "Assignment method" : "Metoda przydzielenia",
    "Automatically assign participants" : "Automatycznie przypisz uczestników",
    "Manually assign participants" : "Ręcznie przypisz uczestników",
    "Allow participants to choose" : "Zezwalaj uczestnikom wybrać",
    "Create rooms" : "Utwórz pokoje",
    "Confirm" : "Potwierdź",
    "Create breakout rooms" : "Twórz pokoje podgrup",
    "Reset" : "Resetuj",
    "Delete breakout rooms" : "Usuń pokoje podgrup",
    "Room {roomNumber}" : "Pokój {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Bieżące pokoje podgrup i ustawienia zostaną utracone",
    "Cancel" : "Anuluj",
    "Unassigned participants" : "Nieprzypisani uczestnicy",
    "Back" : "Wstecz",
    "Assign" : "Przydziel",
    "Add participant \"{user}\"" : "Dodaj uczestnika \"{user}\"",
    "Now" : "Teraz",
    "Invalid calendar selected" : "Wybrano nieprawidłowy kalendarz",
    "Invalid start time selected" : "Wybrano nieprawidłową godzinę rozpoczęcia",
    "Invalid end time selected" : "Wybrano nieprawidłowy czas zakończenia",
    "Unknown error occurred" : "Wystąpił nieznany błąd",
    "Sending no invitations" : "Brak wysyłań zaproszeń",
    "{participant0} will receive an invitation" : "{participant0} otrzyma zaproszenie",
    "{participant0} and {participant1} will receive invitations" : "{participant0} i {participant1} otrzymają zaproszenia",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} i %n inna osoba otrzymają zaproszenia","{participant0}, {participant1} i %n inne osoby otrzymają zaproszenia","{participant0}, {participant1} i %n innych osób otrzymają zaproszenia","{participant0}, {participant1} i %n innych osób otrzymają zaproszenia"],
    "Invite {user}" : "Zaproś {user}",
    "Invite all users and emails in this conversation" : "Zaproś wszystkich użytkowników i adresy e-mail w tej rozmowie",
    "Meeting created" : "Spotkanie utworzone",
    "Upcoming meetings" : "Nadchodzące spotkania",
    "No upcoming meetings" : "Brak zaplanowanych spotkań",
    "Schedule a meeting" : "Zaplanuj spotkanie",
    "Meeting title" : "Tytuł spotkania",
    "From" : "Z",
    "To" : "Na",
    "Calendar" : "Kalendarz",
    "Attendees" : "Uczestnicy",
    "No other participants to send invitations to." : "Brak innych uczestników do zaproszenia.",
    "Add attendees" : "Dodaj uczestników",
    "Save" : "Zapisz",
    "Search participants" : "Wyszukaj uczestników",
    "No results" : "Brak wyników",
    "Done" : "Gotowe",
    "Disable live transcription" : "Wyłącz transkrypcję na żywo",
    "Enable live transcription (generated by AI)" : "Włącz transkrypcję na żywo (generowaną przez AI)",
    "Enable live transcription (Live transcriptions app is not installed)" : "Włącz transkrypcję na żywo (aplikacja Live transcriptions nie jest zainstalowana)",
    "Disable live translation" : "Wyłącz tłumaczenie na żywo",
    "Enable live translation (generated by AI)" : "Włącz tłumaczenie na żywo (generowane przez AI)",
    "Original language" : "Język oryginalny",
    "Live translations app is not installed" : "Aplikacja Live translations nie jest zainstalowana",
    "Original language: {languageName}" : "Język oryginalny: {languageName}",
    "Translated language" : "Język tłumaczenia",
    "Translated language: {languageName}" : "Język tłumaczenia: {languageName}",
    "Exit full screen (F)" : "Wyjdź z trybu pełnoekranowego (F)",
    "Full screen (F)" : "Tryb pełnoekranowy (F)",
    "Speaker view" : "Widok mówcy",
    "Grid view" : "Widok siatki",
    "Error when trying to load the available live transcription languages" : "Błąd podczas próby załadowania dostępnych języków transkrypcji na żywo",
    "Failed to enable live transcription" : "Nie udało się włączyć transkrypcji na żywo",
    "Failed to enable live translations" : "Nie udało się włączyć tłumaczeń na żywo",
    "Failed to disable live translations" : "Nie udało się wyłączyć tłumaczeń na żywo",
    "Recording consent is required" : "Wymagana jest zgoda na nagrywanie",
    "This conversation is read-only" : "Ta rozmowa jest tylko do odczytu",
    "Conversation not found or not joined" : "Nie znaleziono rozmowy lub nie dołączono do niej",
    "Lobby is still active and you're not a moderator" : "Poczekalnia jest nadal aktywna i nie jesteś moderatorem",
    "Connection failed" : "Błąd połączenia",
    "Reload" : "Przeładuj",
    "{nickName} raised their hand." : "{nickName} podniósł rękę.",
    "A participant raised their hand." : "Uczestnik podniósł rękę.",
    "Collapse stripe" : "Zwiń pasek",
    "Expand stripe" : "Rozwiń pasek",
    "Previous page of videos" : "Poprzednia strona obrazów wideo",
    "Next page of videos" : "Następna strona obrazów wideo",
    "Connecting …" : "Łączę…",
    "Calling …" : "Łączenie…",
    "Waiting for {user} to join the call" : "Oczekiwanie na {user}, aż dołączy do połączenia",
    "Waiting for others to join the call …" : "Oczekiwanie na dołączenie się pozostałych do połączenia…",
    "You can invite others in the participant tab of the sidebar" : "Możesz zapraszać inne osoby z zakładki uczestników na pasku bocznym",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Możesz zapraszać inne osoby z zakładki uczestników na pasku bocznym lub udostępnić ten link do zaproszenia!",
    "Share this link to invite others!" : "Udostępnij ten link, aby zaprosić inne osoby!",
    "Copy link" : "Kopiuj link",
    "You are not allowed to enable audio" : "Nie możesz włączyć dźwięku",
    "No audio. Click to select device" : "Bez dźwięku. Kliknij, aby wybrać urządzenie",
    "Mute audio" : "Wycisz dźwięk",
    "Mute audio (M)" : "Wycisz dźwięk (M)",
    "Unmute audio" : "Wyłącz wyciszenie dźwięku",
    "Unmute audio (M)" : "Wyłącz wyciszenie dźwięku (M)",
    "None" : "Żaden",
    "Select a microphone" : "Wybierz mikrofon",
    "Select a speaker" : "Wybierz głośnik",
    "Microphone settings" : "Ustawienia mikrofonu",
    "Check devices" : "Sprawdź urządzenia",
    "Access to camera was denied" : "Odmowa dostępu do kamery",
    "Error while accessing camera: It is likely in use by another program" : "Błąd podczas uzyskiwania dostępu do kamery: Prawdopodobnie jest używana przez inny program",
    "Error while accessing camera" : "Wystąpił błąd podczas dostępu do kamery",
    "You have been muted by a moderator" : "Zostałeś wyciszony przez moderatora",
    "Hide presenter video" : "Ukryj wideo prezentera",
    "You are not allowed to enable video" : "Nie możesz włączyć obrazu wideo",
    "No video. Click to select device" : "Brak wideo. Kliknij, aby wybrać urządzenie",
    "Disable video" : "Wyłącz obraz wideo",
    "Disable video (V)" : "Wyłącz obraz wideo (V)",
    "Enable video" : "Włącz obraz wideo",
    "Enable video (V)" : "Włącz obraz wideo (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Włącz obraz wideo — połączenie zostanie na chwilę przerwane przy pierwszym włączeniu obrazu wideo",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Włącz obraz wideo (V) - Twoje połączenie zostanie na chwilę przerwane po pierwszym włączeniu obrazu wideo",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Włącz obraz wideo. Twoje połączenie zostanie na chwilę przerwane po pierwszym włączeniu obrazu wideo",
    "Select a video device" : "Wybierz urządzenie wideo",
    "Show presenter" : "Pokaż prezentera",
    "You" : "Ty",
    "Mute" : "Wycisz",
    "Muted" : "Wyciszony",
    "Show screen" : "Pokaż ekran",
    "Stop following" : "Zakończ obserwowanie",
    "Connection could not be established …" : "Nie udało się nawiązać połączenia…",
    "Connection was lost and could not be re-established …" : "Połączenie zostało utracone i nie można go było przywrócić…",
    "Connection could not be established. Trying again …" : "Nie udało się nawiązać połączenia. Ponowna próba…",
    "Connection lost. Trying to reconnect …" : "Utracono połączenie. Ponowna próba połączenia…",
    "Connection problems …" : "Problemy z połączeniem…",
    "Collapse" : "Zwiń",
    "Expand" : "Rozwiń",
    "You need to be logged in to upload files" : "Musisz się zalogować, aby wysyłać pliki",
    "Drop your files to upload" : "Upuść swoje pliki do wysłania",
    "Conversation messages" : "Wiadomości w rozmowie",
    "Scroll to bottom" : "Przewiń do dołu",
    "Post message" : "Wyślij wiadomość",
    "Federated conversation" : "Rozmowa federacyjna",
    "Public conversation" : "Rozmowa publiczna",
    "Favorite" : "Ulubione",
    "Banned users" : "Zbanowani użytkownicy",
    "Manage the list of banned users in this conversation." : "Zarządzaj listą zablokowanych użytkowników w tej rozmowie.",
    "Manage bans" : "Zarządzanie blokadami",
    "No banned users" : "Brak zbanowanych użytkowników",
    "Banned by:" : "Zablokowany przez:",
    "Date:" : "Data:",
    "Note:" : "Notatka:",
    "Hide details" : "Ukryj szczegóły",
    "Show details" : "Pokaż szczegóły",
    "Unban" : "Odblokuj",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Możesz zmienić tytuł i opis w Kalendarzu {linkstart} ↗ {linkend}.",
    "Error while updating conversation name" : "Błąd podczas aktualizowania nazwy rozmowy",
    "Error while updating conversation description" : "Błąd podczas aktualizowania opisu rozmowy",
    "Enter a name for this conversation" : "Wpisz nazwę tej rozmowy",
    "Edit conversation name" : "Edytuj nazwę rozmowy",
    "Edit conversation description" : "Edytuj opis rozmowy",
    "Enter a description for this conversation" : "Podaj opis dla tej rozmowy",
    "Picture" : "Obraz",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "W tej rozmowie można włączyć następujące boty. Skontaktuj się z administracją, aby zainstalować więcej botów na tym serwerze.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Na tym serwerze nie są zainstalowane żadne boty. Skontaktuj się z administracją, aby zainstalować boty na tym serwerze.",
    "Disable" : "Wyłącz",
    "Enable" : "Włącz",
    "The bot is not available anymore" : "Bot nie jest już dostępny",
    "Breakout rooms" : "Pokoje podgrup",
    "Manage breakout rooms" : "Zarządzaj pokojami podgrup",
    "Set up breakout rooms for this conversation" : "Skonfiguruj pokoje podgrup dla tej rozmowy",
    "Please select a valid PNG or JPG file" : "Wybierz prawidłowy plik PNG lub JPG",
    "Choose your conversation picture" : "Wybierz obraz rozmowy",
    "Choose" : "Wybierz",
    "Error setting conversation picture" : "Błąd podczas ustawiania obrazu rozmowy",
    "Could not set the conversation picture: {error}" : "Nie można ustawić obrazu rozmowy: {error}",
    "Error cropping conversation picture" : "Błąd podczas przycinania obrazu rozmowy",
    "Error removing conversation picture" : "Błąd podczas usuwania obrazu rozmowy",
    "Set emoji as conversation picture" : "Ustaw emoji jako obraz rozmowy",
    "Set background color for conversation picture" : "Ustaw kolor tła obrazu rozmowy",
    "Upload conversation picture" : "Wyślij obraz rozmowy",
    "Choose conversation picture from files" : "Wybierz obraz rozmowy z plików",
    "Remove conversation picture" : "Usuń obraz rozmowy",
    "The file must be a PNG or JPG" : "Plik musi być w formacie PNG lub JPG",
    "Set picture" : "Ustaw obraz",
    "Default permissions modified for {conversationName}" : "Zmieniono uprawnienia domyślne dla {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Nie udało się zmienić uprawnień domyślnych dla {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Edytuj domyślne uprawnienia uczestników tej rozmowy. Te ustawienia nie mają wpływu na moderatorów.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Za każdym razem, gdy uprawnienia zostaną zmodyfikowane w tej sekcji, uprawnienia niestandardowe wcześniej przypisane poszczególnym uczestnikom zostaną utracone.",
    "All permissions" : "Wszystkie uprawnienia",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Uczestnicy mają uprawnienia do rozpoczynania połączenia, dołączania do rozmowy, włączania dźwięku i obrazu wideo oraz udostępniania ekranu.",
    "Participants can use all available features." : "Uczestnicy mogą korzystać ze wszystkich dostępnych funkcji.",
    "Restricted" : "Ograniczone",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Uczestnicy mogą dołączać do połączeń, ale nie mogą włączać dźwięku i obrazu wideo ani udostępniać ekranu, dopóki moderator nie przyzna im odpowiednich uprawnień.",
    "Participants get a reduced feature set until a moderator manually grants additional permissions." : "Uczestnicy mają ograniczony zestaw funkcji, dopóki moderator ręcznie nie przyzna dodatkowych uprawnień.",
    "Advanced permissions" : "Uprawnienia zaawansowane",
    "Edit permissions" : "Edytuj uprawnienia",
    "Conversation settings" : "Ustawienia rozmowy",
    "Basic Info" : "Podstawowa informacja",
    "Personal" : "Osobiste",
    "Moderation" : "Moderacja",
    "Setup overview" : "Przegląd konfiguracji",
    "Live transcription" : "Transkrypcja na żywo",
    "Live transcriptions app is not installed" : "Aplikacja Live transcriptions nie jest zainstalowana",
    "Enable live transcription" : "Włącz transkrypcję na żywo",
    "Breakout Rooms" : "Pokoje podgrup",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Boty",
    "Danger zone" : "Strefa niebezpieczeństwa",
    "Archive conversation" : "Archiwizuj rozmowę",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Zarchiwizowane rozmowy są domyślnie ukryte na liście konwersacji. Jednak nadal będą się pojawiać, gdy wyszukasz nazwę rozmowy lub uzyskasz dostęp do listy zarchiwizowanych rozmów.",
    "Do you really want to leave \"{displayName}\"?" : "Czy naprawdę chcesz opuścić \"{displayName}\"?",
    "You can archive this conversation instead." : "Zamiast tego możesz zarchiwizować tę rozmowę.",
    "Leave conversation" : "Opuść rozmowę",
    "You need to promote a new moderator before you can leave the conversation" : "Zanim opuścisz rozmowę, musisz wybrać nowego moderatora",
    "Delete conversation" : "Usuń rozmowę",
    "Do you really want to delete \"{displayName}\"?" : "Czy na pewno chcesz usunąć \"{displayName}\"?",
    "Error while deleting conversation" : "Błąd podczas usuwania rozmowy",
    "Delete all chat messages" : "Usuń wszystkie wiadomości czatu",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Czy na pewno chcesz usunąć wszystkie wiadomości w \"{displayName}\"?",
    "Error while clearing chat history" : "Błąd podczas czyszczenia historii czatu",
    "Be careful, these actions cannot be undone." : "Uważaj, tych działań nie można cofnąć.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Po opuszczeniu rozmowy, aby ponownie dołączyć do zamkniętej rozmowy, potrzebne będzie zaproszenie. Do otwartej rozmowy będzie można dołączyć w dowolnym momencie.",
    "Permanently delete this conversation." : "Usuń trwale rozmowę.",
    "Delete chat messages" : "Usuń wiadomości czatu",
    "Permanently delete all the messages in this conversation." : "Usuń trwale wszystkie wiadomości w tej rozmowie.",
    "Custom expiration time" : "Własny czas wygaśnięcia",
    "Message expiration disabled" : "Wygaśnięcie wiadomości wyłączone",
    "Message expiration set: {duration}" : "Ustawione wygaśnięcie wiadomości: {duration}",
    "Error when trying to set message expiration" : "Błąd podczas próby ustawienia wygaśnięcia wiadomości",
    "Message expiration" : "Wygaśnięcie wiadomości",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Wiadomości na czacie mogą wygasnąć po pewnym czasie. Uwaga: pliki udostępnione na czacie nie zostaną usunięte dla właściciela, ale nie będą już udostępniane w rozmowie.",
    "Set message expiration" : "Ustaw datę ważności wiadomości",
    "Current message expiration" : "Aktualny termin ważności wiadomości",
    "Password copied to clipboard" : "Hasło skopiowano do schowka",
    "Password could not be copied" : "Nie można skopiować hasła",
    "Guest access" : "Dostęp dla gościa",
    "Breakout rooms are not allowed in public conversations." : "Podczas publicznych rozmów nie wolno korzystać z pokoi spotkań.",
    "Allow guests to join this conversation via link" : "Zezwalaj gościom na dołączenie do tej rozmowy za pomocą linku",
    "Password protection" : "Ochrona hasłem",
    "This conversation is password-protected. Guests need password to join" : "Rozmowa jest chroniona hasłem. Goście potrzebują hasła, aby dołączyć",
    "Password protection is needed for public conversations" : "Ochrona hasłem jest wymagana w przypadku rozmów publicznych",
    "Set a password" : "Ustaw hasło",
    "Change password" : "Zmień hasło",
    "Enter new password" : "Wprowadź nowe hasło",
    "Save password" : "Zapisz hasło",
    "Copy password" : "Kopiuj hasło",
    "Guests are allowed to join this conversation via link" : "Goście mogą dołączyć do tej rozmowy za pomocą linku",
    "Guests are not allowed to join this conversation" : "Goście nie mogą przyłączać się do tej rozmowy",
    "Resend invitations" : "Wyślij ponownie zaproszenia",
    "This conversation is open to both registered users and users created with the Guests app" : "Rozmowa jest dostępna zarówno dla zarejestrowanych użytkowników, jak i użytkowników utworzonych za pomocą aplikacji Goście",
    "This conversation is open to registered users" : "Rozmowa jest dostępna dla zarejestrowanych użytkowników",
    "This conversation is limited to the current participants" : "Rozmowa jest ograniczona do obecnych uczestników",
    "You opened the conversation to both registered users and users created with the Guests app" : "Otworzyłeś rozmowę zarówno dla zarejestrowanych użytkowników, jak i użytkowników utworzonych za pomocą aplikacji Goście",
    "Error occurred when opening or limiting the conversation" : "Wystąpił błąd podczas otwierania lub ograniczania rozmowy",
    "Open conversation to registered users, showing it in search results" : "Otwórz rozmowę dla zarejestrowanych użytkowników, pokazując ją w wynikach wyszukiwania",
    "Also open to users created with the Guests app" : "Dostępne także dla użytkowników utworzonych za pomocą aplikacji Goście",
    "Open conversation" : "Otwarta rozmowa",
    "Set language spoken in calls" : "Ustaw język używany podczas rozmów",
    "Languages could not be loaded" : "Nie udało się załadować języków",
    "Loading languages …" : "Ładowanie języków ...",
    "Invalid language" : "Nieprawidłowy język",
    "Default language (English)" : "Domyślny język (angielski)",
    "Default live transcription language set" : "Ustawiono domyślny język transkrypcji na żywo",
    "Live transcription language set: {languageName}" : "Ustawiono język transkrypcji na żywo: {languageName}",
    "Error when trying to set live transcription language" : "Błąd podczas próby ustawienia języka transkrypcji na żywo",
    "Start time: {date}" : "Godzina rozpoczęcia: {date}",
    "Start time has been updated" : "Czas rozpoczęcia został zaktualizowany",
    "Error occurred while updating start time" : "Wystąpił błąd podczas aktualizowania czasu rozpoczęcia",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Włączenie poczekalni spowoduje usunięcie osób niebędących moderatorami z trwającej rozmowy.",
    "Enable lobby, restricting the conversation to moderators" : "Włącz poczekalnię, ograniczając rozmowę dla moderatorów",
    "Meeting start time" : "Czas rozpoczęcia spotkania",
    "Start time (optional)" : "Czas rozpoczęcia (opcjonalnie)",
    "Import email participants" : "Importuj uczestników z adresów e-mail",
    "You can import a list of email participants from a CSV file." : "Listę uczestników adresów e-mail można zaimportować z pliku CSV.",
    "Poll drafts" : "Projekty ankiet",
    "Browse poll drafts" : "Przeglądaj projekty sond",
    "Error occurred when locking the conversation" : "Wystąpił błąd podczas zablokowywania rozmowy",
    "Error occurred when unlocking the conversation" : "Wystąpił błąd podczas odblokowywania rozmowy",
    "Lock conversation" : "Zablokuj rozmowę",
    "This will also terminate the ongoing call." : "Spowoduje to również zakończenie trwającego połączenia.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Zablokuj rozmowę, aby nikt nie mógł publikować wiadomości ani rozpoczynać połączeń",
    "Edit" : "Edytuj",
    "More information" : "Więcej informacji",
    "Delete" : "Usuń",
    "Add new bridged channel to current conversation" : "Dodaj nowy zmostkowany kanał do bieżącej rozmowy",
    "unknown state" : "stan nieznany",
    "running" : "uruchomiony",
    "not running, check Matterbridge log" : "nie działa, sprawdź dziennik Matterbridge",
    "not running" : "nie działa",
    "Bridge saved" : "Połączenie zapisane",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Możesz łączyć kanały z różnych systemów wiadomości natychmiastowych z Matterbridge.",
    "More info on Matterbridge" : "Więcej informacji o Matterbridge",
    "Messaging systems" : "Wiadomości systemowe",
    "Enable bridge" : "Włącz mostkowanie",
    "Show Matterbridge log" : "Pokaż dziennik Matterbridge",
    "Log content" : "Zawiera",
    "Only moderators are allowed to mention @all" : "Tylko moderatorzy mogą wspominać dla @all",
    "All participants are allowed to mention @all" : "Wszyscy uczestnicy mogą wspomnieć dla @all",
    "Participants are now allowed to mention @all." : "Uczestnicy mogą teraz wspominać dla @all.",
    "Mentioning @all has been limited to moderators." : "Wzmianki @all są dostępne wyłącznie dla moderatorów.",
    "Allow participants to mention @all" : "Zezwalaj uczestnikom na wspominanie @all",
    "Mention permissions" : "Wspomnij o uprawnieniach",
    "Notifications" : "Powiadomienia",
    "Notify about calls in this conversation" : "Powiadamiaj o połączeniach w tej rozmowie",
    "Important conversation" : "Ważna rozmowa",
    "\"Do not disturb\" user status is ignored for important conversations" : "Status użytkownika „Nie przeszkadzać” jest ignorowany dla ważnych rozmów.",
    "Sensitive conversation" : "Rozmowa poufna",
    "Message preview will be disabled in conversation list and notifications" : "Podgląd wiadomości zostanie wyłączony na liście rozmów i w powiadomieniach.",
    "Recording consent is required for calls in this conversation" : "W przypadku rozmów w tym połączeniu wymagana jest zgoda na nagrywanie",
    "Recording consent is not required for calls in this conversation" : "W przypadku rozmów w tym połączeniu nie jest wymagana zgoda na nagrywanie",
    "Recording consent requirement was updated" : "Zaktualizowano wymóg dotyczący zgody na nagrywanie",
    "Error occurred while updating recording consent" : "Wystąpił błąd podczas aktualizowania zgody na nagrywanie",
    "Recording Consent" : "Zgoda na nagrywanie",
    "Recording consent cannot be changed once a call or breakout session has started." : "Zgody na nagrywanie nie można zmienić po rozpoczęciu rozmowy lub sesji grupowej.",
    "Require recording consent before joining call in this conversation" : "Wymagaj zgody na nagrywanie przed dołączeniem do tej rozmowy",
    "Recording consent is required for all calls" : "W przypadku wszystkich połączeń wymagana jest zgoda na nagrywanie",
    "SIP dial-in is now possible without PIN requirement" : "Połączenie telefoniczne SIP jest teraz możliwe bez konieczności podawania kodu PIN",
    "SIP dial-in is now enabled" : "Połączenie telefoniczne SIP jest teraz włączone",
    "SIP dial-in is now disabled" : "Połączenie telefoniczne SIP jest teraz wyłączone",
    "Error occurred when enabling SIP dial-in" : "Wystąpił błąd podczas włączania połączenia telefonicznego SIP",
    "Error occurred when disabling SIP dial-in" : "Wystąpił błąd podczas wyłączania połączenia telefonicznego SIP",
    "Phone and SIP dial-in" : "Połączenie telefoniczne i SIP",
    "Enable phone and SIP dial-in" : "Włącz połączenie telefoniczne i SIP",
    "Allow to dial-in without a PIN" : "Zezwalaj na połączenie telefoniczne bez kodu PIN",
    "Ongoing" : "Trwające",
    "{dayPrefix} {dateTime}" : "{dayPrefix}{dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["Zaakceptowane przez %n osobę","Zaakceptowane przez %n osoby","Zaakceptowało %n osób","Zaakceptowało %nosób"],
    "_%n person declined_::_%n people declined_" : ["%n osoba odrzuciła","%n osoby odrzuciły","%n osób odrzuciło","%n osób odrzuciło"],
    "_and %n other attachment_::_and %n other attachments_" : ["i %n inny załącznik","i %n inne załączniki","i %n innych załączników","i %n innych załączników"],
    "With {displayName}" : "Z {displayName}",
    "In {conversation}" : "w {conversation}",
    "View attachment" : "Wyświetl załącznik",
    "Join" : "Dołącz",
    "View conversation" : "Pokaż rozmowę",
    "View event on Calendar" : "Pokaż zdarzenie w Kalendarzu",
    "Error while creating the conversation" : "Błąd podczas tworzenia rozmowy",
    "Hello, {displayName}" : "Witaj, {displayName}",
    "Start meeting now" : "Rozpocznij spotkanie",
    "Give your meeting a title" : "Wpisz tytuł swojego spotkania",
    "Create and copy link" : "Utwórz i skopiuj link",
    "Create a new conversation" : "Utwórz nową rozmowę",
    "Join open conversations" : "Dołącz do otwartych rozmów",
    "Call a phone number" : "Zadzwoń pod numer telefonu",
    "Scroll backward" : "Przewiń wstecz",
    "Scroll forward" : "Przewiń do przodu",
    "Schedule meetings" : "Planowanie spotkań",
    "You don't have any upcoming meetings" : "Nie masz żadnych nadchodzących spotkań",
    "Calendar events with a conversation link as the location are shown here" : "Wydarzenia kalendarza z linkiem do rozmowy jako lokalizacją są wyświetlane tutaj",
    "Open calendar" : "Otwórz kalendarz",
    "Unread mentions" : "Nieprzeczytane wzmianki",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Wiadomości, w których zostałeś wspomniany, pojawią się tutaj. Możesz wspominać ludzi, wpisując @ i ich nazwę",
    "Upcoming reminders" : "Nadchodzące przypomnienia",
    "Message reminders" : "Przypomnienia wiadomości",
    "Set a reminder on a message to be notified" : "Ustaw przypomnienie dla wiadomości, aby otrzymać powiadomienie",
    "Start a group conversation" : "Rozpocznij rozmowę grupową",
    "Create conversation" : "Utwórz rozmowę",
    "Enter your name" : "Wpisz swoją nazwę",
    "Submit name and join" : "Podaj nazwę i dołącz",
    "Do you already have an account?" : "Czy masz już konto?",
    "Log in" : "Zaloguj się",
    "Error while verifying uploaded file" : "Wystąpił błąd podczas weryfikacji przesłanego pliku",
    "Uploaded file is verified" : "Wysłany plik został zweryfikowany",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Format treści to wartości rozdzielone przecinkami (CSV):<br/>- Wiersz nagłówka jest wymagany i musi odpowiadać słowom <samp>\"name\",\"email\"</samp> lub po prostu <samp>\"email\"</samp><br/>- Jeden wpis w wierszu (np. <samp>\"Jan Kowalski\",\"jan@przyklad.pl\"</samp>)",
    "Participants added successfully" : "Uczestnicy dodani pomyślnie",
    "Error while adding participants" : "Błąd podczas dodawania uczestników",
    "Import a file" : "Importuj plik",
    "Browse" : "Przeglądaj",
    "Verifying uploaded file …" : "Weryfikacja przesłanego pliku…",
    "This might take a moment" : "To może chwilę potrwać.",
    "Send invitations" : "Wyślij zaproszenia",
    "_%n invalid email_::_%n invalid emails_" : ["%n adres e-mail nieprawidłowy","%n adresy e-mail nieprawidłowe","%n adresów e-mail nieprawidłowych","%n adresów e-mail nieprawidłowych"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n adres e-mail został już zaimportowanych lub jest duplikatem","%n adresy e-mail zostały już zaimportowane lub są duplikatami","%n adresów e-mail zostało już zaimportowanych lub są duplikatami","%n adresów e-mail zostało już zaimportowanych lub są duplikatami"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["Można wysłać %n zaproszenie","Można wysłać %n zaproszenia","Można wysłać %n zaproszeń","Można wysłać %n zaproszeń"],
    "An error occurred while calling a phone number" : "Wystąpił błąd podczas wybierania numeru telefonu",
    "Phone number could not be called: {error}" : "Nie można było zadzwonić pod numer telefonu: {error}",
    "Phone number could not be called" : "Nie można było zadzwonić pod numer telefonu",
    "Search participants or phone numbers" : "Wyszukaj uczestników lub numery telefonów",
    "Creating the conversation …" : "Tworzenie rozmowy…",
    "Mark as read" : "Oznacz jako przeczytane",
    "Mark as unread" : "Oznacz jako nieprzeczytane",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add to favorites" : "Dodaj do ulubionych",
    "Unarchive conversation" : "Przywróć archiwum rozmowy",
    "Ignore \"Do not disturb\"" : "Ignoruj \"Nie przeszkadzać\"",
    "You need to promote a new moderator before you can leave the conversation." : "Zanim opuścisz rozmowę, musisz wybrać nowego moderatora.",
    "New tag" : "Nowa etykieta",
    "Tag name" : "Nazwa etykiety",
    "Conversation actions" : "Akcje rozmowy",
    "Tags" : "Etykiety",
    "Notify about calls" : "Powiadom o połączeniach",
    "Hide message text" : "Ukryj treść wiadomości",
    "Remove all tags" : "Usuń wszystkie tagi",
    "Rename tag" : "Zmień nazwę etykiety",
    "Delete tag" : "Usuń etykiety",
    "Do you really want to delete \"{name}\"? Conversations with this tag will be moved to \"Other\"." : "Czy na pewno chcesz usunąć \"{name}\"? Rozmowy z tym tagiem zostaną przeniesione do \"Inne\".",
    "Move up" : "Przenieś wyżej",
    "Move down" : "Przenieś niżej",
    "Pending invitations" : "Oczekujące zaproszenia",
    "Join conversations from other servers" : "Dołącz do rozmów z innych serwerów",
    "From {user} at {remoteServer}" : "Od {user} z {remoteServer}",
    "Decline invitation" : "Odrzuć zaproszenie",
    "Accept invitation" : "Zaakceptuj zaproszenie",
    "No pending invitations" : "Brak oczekujących zaproszeń",
    "Home" : "Strona główna",
    "Unread" : "Nieprzeczytane",
    "Mentions" : "Wzmianki",
    "Meetings" : "Spotkania",
    "Sort conversations" : "Sortuj rozmowy",
    "By recent activity" : "Według ostatniej aktywności",
    "Alphabetically" : "Alfabetycznie",
    "Do not group by type" : "Nie grupuj według typu",
    "Show private ones first" : "Najpierw pokazuj prywatne",
    "Show group ones first" : "Najpierw pokazuj grupowe",
    "No followed threads" : "Brak obserwowanych wątków",
    "No matches found" : "Nie znaleziono pasujących",
    "No conversations found" : "Nie znaleziono rozmów",
    "You have no archived conversations." : "Nie masz żadnych zarchiwizowanych rozmów.",
    "Subscribe to an existing thread or start your own." : "Zasubskrybuj istniejący wątek lub rozpocznij własny.",
    "You have no unread mentions." : "Nie masz nieprzeczytanych wzmianek.",
    "You have no unread messages." : "Nie masz nieprzeczytanych wiadomości.",
    "An error occurred while performing the search" : "Wystąpił błąd podczas wyszukiwania",
    "Conversation list" : "Lista rozmów",
    "Filter conversations by" : "Filtruj rozmowy po",
    "Unread messages" : "Nieprzeczytane wiadomości",
    "Meeting conversations" : "Rozmowy spotkań",
    "Clear filters" : "Wyczyść filtry",
    "New personal note" : "Nowa notatka osobista",
    "SIP backend is not installed" : "Backend SIP nie jest zainstalowany",
    "Back to conversations" : "Powrót do rozmów",
    "Threads" : "Wątki",
    "Archived conversations" : "Zarchiwizowane rozmowy",
    "Clear filter" : "Wyczyść filtr",
    "Show more threads" : "Pokaż więcej wątków",
    "App settings" : "Ustawienia aplikacji",
    "Users" : "Użytkownicy",
    "Groups" : "Grupy",
    "Teams" : "Zespoły",
    "Federated users" : "Użytkownicy federacyjni",
    "New private conversation" : "Nowa rozmowa prywatna",
    "Other sources" : "Inne źródła",
    "Open conversations" : "Otwarte rozmowy",
    "No search results" : "Brak wyników wyszukiwania",
    "Users, groups and teams" : "Użytkownicy, grupy i zespoły",
    "Users and groups" : "Użytkownicy i grupy",
    "Users and teams" : "Użytkownicy i zespoły",
    "Groups and teams" : "Grupy i zespoły",
    "New group conversation" : "Nowa rozmowa grupowa",
    "The meeting will start soon" : "Spotkanie wkrótce się rozpocznie",
    "This meeting is scheduled for {startTime}" : "Spotkanie jest zaplanowane na {startTime}",
    "You are currently waiting in the lobby" : "Obecnie czekasz w poczekalni",
    "Enable noise suppression" : "Włącz redukcję szumów",
    "Reduce background noises for better voice quality" : "Zredukuj szumy tła, aby poprawić jakość dźwięku",
    "Basic" : "Podstawowe",
    "Advanced" : "Zaawansowane",
    "Enable echo cancellation" : "Włącz eliminację echa",
    "Minimize echo effect from own surrounding" : "Minimalizuj efekt echa z otoczenia",
    "Enable auto gain control" : "Włącz automatyczną regulację wzmocnienia",
    "Dynamically adjust microphone volume for consistent level" : "Dynamicznie dostosuj głośność mikrofonu, aby utrzymać stały poziom",
    "Select microphone" : "Wybierz mikrofon",
    "No microphone available" : "Brak dostępnego mikrofonu",
    "Select speaker" : "Wybierz głośnik",
    "No speaker available" : "Brak dostępnych głośników",
    "Select camera" : "Wybierz kamerę",
    "No camera available" : "Brak dostępnej kamery",
    "Select a device" : "Wybierz urządzenie",
    "Playing …" : "Odtwarzanie…",
    "Test speakers" : "Test głośników",
    "Test" : "Test",
    "Devices" : "Urządzenia",
    "Backgrounds" : "Tła",
    "No audio" : "Brak dźwięku",
    "No camera" : "Brak kamery",
    "Display video as you will see it (mirrored)" : "Wyświetl wideo tak, jak je widzisz (odbicie lustrzane)",
    "Display video as others will see it" : "Wyświetlaj wideo tak, jak będą je widzieć inni",
    "Calls are not supported in your browser" : "Twoja przeglądarka nie obsługuje połączeń",
    "Access to microphone is only possible with HTTPS" : "Dostęp do mikrofonu jest możliwy tylko przy użyciu protokołu HTTPS",
    "Access to microphone was denied" : "Odmowa dostępu do mikrofonu",
    "Error while accessing microphone" : "Błąd podczas uzyskiwania dostępu do mikrofonu",
    "Access to camera is only possible with HTTPS" : "Dostęp do kamery jest możliwy tylko przy użyciu protokołu HTTPS",
    "The call is being recorded." : "Rozmowa jest nagrywana.",
    "The call might be recorded." : "Rozmowa może zostać nagrana.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Nagranie może obejmować Twój głos, wideo z kamery i udostępniony ekran. Przed dołączeniem do rozmowy wymagana jest Twoja zgoda.",
    "Give consent to the recording of this call" : "Wyraź zgodę na nagrywanie tej rozmowy",
    "Show more info" : "Pokaż więcej informacji",
    "Audio is not available" : "Dźwięk jest niedostępny",
    "Video is not available" : "Wideo jest niedostępne",
    "Start recording immediately with the call" : "Rozpocznij nagrywanie natychmiast po połączeniu",
    "Recording backend is not installed" : "Backend nagrywania nie jest zainstalowany",
    "Notify all participants about this call" : "Powiadom wszystkich uczestników o tym połączeniu",
    "Apply settings" : "Zastosuj ustawienia",
    "Select virtual office background" : "Wybierz tło wirtualnego biura",
    "Select virtual home background" : "Wybierz tło wirtualnego domu",
    "Select virtual abstract background" : "Wybierz wirtualne abstrakcyjne tło",
    "Select virtual beach background" : "Wybierz tło wirtualnej plaży",
    "Select virtual park background" : "Wybierz tło wirtualnego parku",
    "Select virtual theater background" : "Wybierz tło wirtualnego teatru",
    "Select virtual library background" : "Wybierz tło wirtualnej biblioteki",
    "Select virtual space station background" : "Wybierz tło wirtualnej stacji kosmicznej",
    "Error while uploading the file" : "Błąd podczas wysyłania pliku",
    "Select a file" : "Wybierz plik",
    "Invalid path selected" : "Wybrano nieprawidłową ścieżkę",
    "Select virtual background from file {fileName}" : "Wybierz wirtualne tło z pliku {fileName}",
    "Blur" : "Plama",
    "Upload" : "Wyślij",
    "Files" : "Pliki",
    "(editing)" : "(redagowanie)",
    "(edited)" : "(edytowane)",
    "The message has expired or has been deleted" : "Wiadomość wygasła lub została usunięta",
    "Cancel quote" : "Anuluj cytowanie",
    "24 hours" : "24 godziny",
    "7 days" : "7 dni",
    "30 days" : "30 dni",
    "Until unpin" : "Do odpięcia",
    "Clear reminder – {timeLocale}" : "Wyczyść przypomnienie – {timeLocale}",
    "Edited by {actor}" : "Edytowane przez {actor}",
    "Pinned by you" : "Przypięte przez Ciebie",
    "Pinned by {actor}" : "Przypięte przez {actor}",
    "Until {absoluteDate}" : "Do {absoluteDate}",
    "Message text copied to clipboard" : "Tekst wiadomości skopiowany do schowka",
    "Message text could not be copied" : "Nie udało się skopiować tekstu wiadomości",
    "Message forwarded to \"Note to self\"" : "Wiadomość przekazana do \"Notatka dla siebie\"",
    "Error while forwarding message to \"Note to self\"" : "Błąd podczas przekazywania wiadomości do \"Notatka dla siebie\"",
    "A reminder was successfully removed" : "Przypomnienie zostało pomyślnie usunięte",
    "Error occurred when removing a reminder" : "Wystąpił błąd podczas usuwania przypomnienia",
    "A reminder was successfully set at {datetime}" : "Przypomnienie zostało pomyślnie ustawione na {datetime}",
    "Error occurred when creating a reminder" : "Podczas tworzenia przypomnienia wystąpił błąd",
    "Add a reaction to this message" : "Dodaj reakcję na tę wiadomość",
    "Reply" : "Odpowiedz",
    "More actions" : "Więcej akcji",
    "Set reminder" : "Ustaw przypomnienie",
    "Pin message" : "Przypnij wiadomość",
    "Unpin message" : "Odepnij wiadomość",
    "Reply privately" : "Odpowiedz prywatnie",
    "Edit message" : "Edytuj wiadomość",
    "Copy message" : "Skopiuj wiadomość",
    "Copy message link" : "Kopiuj link wiadomości",
    "Go to file" : "Przejdź do pliku",
    "Download file" : "Pobierz plik",
    "Go to thread" : "Przejdź do wątku",
    "Edit thread details" : "Edytuj szczegóły wątku",
    "Forward message" : "Przekaż wiadomość",
    "Translate" : "Tłumaczenie",
    "Set custom reminder" : "Ustaw niestandardowe przypomnienie",
    "Keep pinned for" : "Zachowaj przypięcie przez",
    "Set custom period" : "Ustaw niestandardowy okres",
    "Close reactions menu" : "Zamknij menu reakcji",
    "React with {emoji}" : "Reakcja za pomocą {emoji}",
    "React with another emoji" : "Reakcja za pomocą innego emoji",
    "Choose a conversation to forward the selected message." : "Wybierz rozmowę, aby przekazać wybraną wiadomość.",
    "Error while forwarding message" : "Błąd podczas przekazywania wiadomości",
    "The message has been forwarded to {selectedConversationName}" : "Wiadomość została przekazana do {selectedConversationName}",
    "Dismiss" : "Odrzuć",
    "Go to conversation" : "Przejdź do rozmowy",
    "Detect language" : "Wykryj język",
    "The message could not be translated" : "Nie udało się przetłumaczyć wiadomości",
    "Translation copied to clipboard" : "Tłumaczenie skopiowane do schowka",
    "Translation could not be copied" : "Nie można skopiować tłumaczenia",
    "Translate message" : "Przetłumacz wiadomość",
    "Source language to translate from" : "Język źródłowy, z którego chcesz tłumaczyć",
    "Translate from" : "Przetłumacz z",
    "Target language to translate into" : "Język docelowy, na który chcesz tłumaczyć",
    "Translate to" : "Przetłumacz na",
    "Translating" : "Tłumaczenie",
    "This translation is AI generated and may contain mistakes." : "To tłumaczenie zostało wygenerowane przez AI i może zawierać błędy",
    "Copy translated text" : "Kopiuj przetłumaczony tekst",
    "Error when scheduling the message" : "Błąd podczas planowania wiadomości",
    "Reschedule" : "Zmień harmonogram",
    "Send now" : "Wyślij teraz",
    "Choose a time" : "Wybierz godzinę",
    "Send at custom time" : "Wyślij o niestandardowej porze",
    "Will be sent without notification" : "Zostanie wysłane bez powiadomienia",
    "Message read by everyone who shares their reading status" : "Wiadomość przeczytana przez wszystkich, którzy udostępniają swój status odczytu",
    "Message sent" : "Wiadomość wysłana",
    "Sent without notification" : "Wysłano bez powiadomienia",
    "Deleting message" : "Usuwanie wiadomości",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Wiadomość została pomyślnie usunięta, ale skonfigurowano bota lub Matterbridge, a wiadomość mogła już zostać przesłana do innych usług",
    "Message deleted successfully" : "Wiadomość została pomyślnie usunięta",
    "Message could not be deleted because it is too old" : "Nie można usunąć wiadomości, ponieważ jest zbyt stara",
    "Only normal chat messages can be deleted" : "Usunąć można tylko zwykłe wiadomości czatu",
    "An error occurred while deleting the message" : "Wystąpił błąd podczas usuwania wiadomości",
    "Pinned" : "Przypięte",
    "Your browser does not support playing audio files" : "Twoja przeglądarka nie obsługuje odtwarzania plików audio",
    "Contact" : "Kontakt",
    "{stack} in {board}" : "{stack} na {board}",
    "Deck Card" : "Karta Deck",
    "Remove {fileName}" : "Usuń {fileName}",
    "Open this location in OpenStreetMap" : "Otwórz lokalizację w OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n odpowiedź","%n odpowiedzi","%n odpowiedzi","%n odpowiedzi"],
    "Sending message" : "Wysyłanie wiadomości",
    "Failed to send the message. Click to try again" : "Nie udało się wysłać wiadomości. Kliknij, aby spróbować ponownie",
    "Not enough free space to upload file" : "Za mało wolnego miejsca, aby wysłać plik",
    "You cannot send messages to this conversation at the moment" : "W tej chwili nie możesz wysyłać wiadomości dla tej rozmowy",
    "Could not update the message" : "Nie udało się zaktualizować wiadomości",
    "Reply to thread \"{threadTitle}\"" : "Odpowiedz w wątku \"{threadTitle}\"",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Oddałeś głos • %n głos","Oddałeś głos • %n głosów","Oddałeś głos • %n głosów","Oddałeś głos  • %n głosy"],
    "You voted" : "Zagłosowałeś",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Kliknij, aby zagłosować • %n głos","Kliknij, aby zagłosować • %n głosów","Kliknij, aby zagłosować • %n głosów","Kliknij, aby zagłosować • %n głosy"],
    "Click to vote" : "Kliknij, aby zagłosować",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Projekt sondy • %n opcja","Projekt sondy • %n opcje","Projekt sondy • %n opcji","Projekt sondy • %n opcji"],
    "_%n vote_::_%n votes_" : ["%n głos","%n głosów","%n głosów","%n głosy"],
    "Edit poll draft" : "Edytuj projekt sondy",
    "Delete poll draft" : "Usuń wersję roboczą ankiety",
    "Open poll" : "Otwórz sondę",
    "Closed poll" : "Głosowanie zamknięte",
    "See results" : "Zobacz wyniki",
    "Reactions" : "Reakcje",
    "No permission to post reactions in this conversation" : "Brak uprawnień do publikowanie reakcji w tej rozmowie",
    "and {participant}" : "i {participant}",
    "_and %n other participant_::_and %n other participants_" : ["i %n inny uczestnik","i %n innych uczestników","i %n innych uczestników","i %n innych uczestników"],
    "Show all reactions" : "Pokaż wszystkie reakcje",
    "Add more reactions" : "Dodaj więcej reakcji",
    "Show or collapse system messages" : "Pokaż lub zwiń komunikaty systemowe",
    "No messages" : "Brak wiadomości",
    "All messages have expired or have been deleted." : "Wszystkie wiadomości wygasły lub zostały usunięte.",
    "Generate summary with AI" : "Wygeneruj podsumowanie za pomocą AI",
    "{author} (pinned by you)" : "{author} (przypięte przez Ciebie)",
    "{author} (pinned by {actor})" : "{author} (przypięte przez {actor})",
    "Unpin" : "Odepnij",
    "Cancel search" : "Anuluj wyszukiwanie",
    "Add a phone number" : "Dodaj numer telefonu",
    "Error: A password is required to create the conversation." : "Błąd: Do utworzenia rozmowy wymagane jest hasło.",
    "All set, the conversation \"{conversationName}\" was created." : "Wszystko gotowe, rozmowa \"{conversationName}\" została utworzona.",
    "Create a new group conversation" : "Utwórz nową rozmowę grupową",
    "Add participants" : "Dodaj uczestników",
    "Maximum length exceeded ({maxlength} characters)" : "Przekroczono maksymalną długość ({maxlength} znaków)",
    "Conversation type" : "Typ rozmowy",
    "Default parameters are:" : "Domyślne parametry to:",
    "These settings can be changed once the conversation is created." : "Te ustawienia można zmienić po utworzeniu rozmowy.",
    "Conversation visibility" : "Widoczność rozmowy",
    "Allow guests to join via link" : "Zezwalaj gościom na dołączanie za pomocą linku",
    "Enter password" : "Wprowadź hasło",
    "This conversation has been locked" : "Ta rozmowa została zablokowana",
    "No permission to post messages in this conversation" : "Brak uprawnień do publikowania wiadomości w tej rozmowie",
    "Joining conversation …" : "Dołączanie do rozmowy…",
    "Write a message without notification" : "Napisz wiadomość bez powiadomienia",
    "Create a thread silently" : "Utwórz wątek po cichu",
    "Create a thread" : "Utwórz wątek",
    "Send message silently" : "Wyślij wiadomość w trybie cichym",
    "Send message" : "Wyślij wiadomość",
    "Send without notification" : "Wyślij bez powiadomienia",
    "The participant will not be notified about new messages" : "Uczestnik nie będzie powiadamiany o nowych wiadomościach",
    "Participants will not be notified about new messages" : "Uczestnicy nie będą powiadamiani o nowych wiadomościach",
    "Message will be sent {datetimeString}" : "Wiadomość zostanie wysłana {datetimeString}",
    "Thread title is required" : "Tytuł wątku jest wymagany",
    "Message text is required" : "Wymagany jest tekst wiadomości",
    "The message could not be edited" : "Wiadomości nie można edytować",
    "File to share" : "Plik do udostępnienia",
    "File upload is not available in this conversation" : "W tej rozmowie nie jest dostępne przesyłanie plików",
    "Message was successfully scheduled" : "Wiadomość została pomyślnie zaplanowana",
    "Add emoji" : "Dodaj emoji",
    "Adding a mention will only notify users who did not read the message." : "Dodanie wzmianki spowoduje powiadomienie tylko użytkowników, którzy nie przeczytali wiadomości.",
    "Thread title" : "Tytuł wątku",
    "Send later" : "Wyślij później",
    "Show scheduled messages" : "Pokaż zaplanowane wiadomości",
    "Cancel editing" : "Anuluj edycję",
    "Schedule message" : "Zaplanuj wiadomość",
    "{user} is out of office and might not respond." : "{user} jest poza biurem i może nie odpowiadać.",
    "Absence period: {startDate} - {endDate}" : "Okres nieobecności: {startDate} - {endDate}",
    "Replacement:" : "Zastępstwo:",
    "Share from {nextcloud}" : "Udostępnij z {nextcloud}",
    "Share from Files" : "Udostępnij z Plików",
    "Share files to the conversation" : "Udostępnij pliki w rozmowie",
    "Upload from device" : "Wyślij z urządzenia",
    "Create new poll" : "Stwórz nową sondę",
    "Smart picker" : "Inteligentna selekcja",
    "Record voice message" : "Nagraj wiadomość głosową",
    "End recording and send" : "Zakończ nagrywanie i wyślij",
    "Dismiss recording" : "Odrzuć nagranie",
    "Access to the microphone was denied" : "Odmowa dostępu do mikrofonu",
    "Microphone either not available or disabled in settings" : "Mikrofon jest niedostępny lub wyłączony w ustawieniach",
    "Error while recording audio" : "Błąd podczas nagrywania dźwięku",
    "Voice message {time} ({conversation})" : "Wiadomość głosowa {time} ({conversation})",
    "Generating summary of unread messages …" : "Trwa generowanie podsumowania nieprzeczytanych wiadomości…",
    "Summary is AI generated and might contain mistakes" : "Podsumowanie jest generowane przez sztuczną inteligencję i może zawierać błędy",
    "Error occurred during a summary generation" : "Wystąpił błąd podczas generowania podsumowania",
    "New file" : "Nowy plik",
    "Blank" : "Pusty",
    "Error while creating file" : "Błąd podczas tworzenia pliku",
    "Create and share a new file" : "Utwórz i udostępnij nowy plik",
    "Name of the new file" : "Nazwa nowego pliku",
    "Create file" : "Utwórz plik",
    "Someone is typing …" : "Ktoś pisze…",
    "{user1} is typing …" : "{user1} pisze…",
    "{user1} and {user2} are typing …" : "{user1} i {user2} piszą…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} i {user3} piszą…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} i %n inny pisze…","{user1}, {user2}, {user3} i %n innych pisze…","{user1}, {user2}, {user3} i %n innych piszą…","{user1}, {user2}, {user3} i %n innych piszą…"],
    "Add more files" : "Dodaj więcej plików",
    "Send" : "Wyślij",
    "In this conversation <strong>{user}</strong> can:" : "W tej rozmowie <strong>{user}</strong> może:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Edytuj uprawnienia domyślne dla uczestników w {conversationName}",
    "Start a call" : "Rozpocznij połączenie",
    "Skip the lobby" : "Pomiń poczekalnie",
    "Can post messages" : "Może publikować wiadomości",
    "Can post messages and reactions" : "Może publikować wiadomości i reakcje",
    "Can add reactions" : "Może dodawać reakcje",
    "Enable the microphone" : "Włącz mikrofon",
    "Enable the camera" : "Włącz kamerę",
    "Share the screen" : "Udostępnij ekran",
    "Update permissions" : "Zaktualizuj uprawnienia",
    "Updating permissions" : "Aktualizowanie uprawnień",
    "No poll drafts" : "Brak wersji roboczych ankiet",
    "There is no poll drafts yet saved for this conversation" : "Dla tej rozmowy nie zapisano jeszcze żadnych wersji roboczych ankiety",
    "Create poll in {name}" : "Utwórz sondę w {name}",
    "Create poll" : "Utwórz sondę",
    "Error while importing poll" : "Błąd podczas importowania ankiety",
    "Question" : "Pytanie",
    "Ask a question" : "Zadaj pytanie",
    "Import draft from file" : "Importuj wersję roboczą z pliku",
    "Answers" : "Odpowiedzi",
    "Answer {option}" : "Odpowiedź {option}",
    "Delete poll option" : "Usuń opcję sondy",
    "Add answer" : "Dodaj odpowiedź",
    "Settings" : "Ustawienia",
    "Anonymous poll" : "Anonimowa sonda",
    "Multiple answers" : "Wiele odpowiedzi",
    "Save as draft" : "Zapisz jako wersję roboczą",
    "Export draft to file" : "Eksportuj wersję roboczą do pliku",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Wyniki końcowe •  %n głos","Wyniki końcowe •  %n głosów","Wyniki końcowe •  %n głosów","Wyniki końcowe •  %n głosów"],
    "_%n vote • Your vote is anonymous_::_%n votes • Your vote is anonymous_" : ["%n głos • Twój głos jest anonimowy","%n głosów • Twój głos jest anonimowy","%n głosów • Twój głos jest anonimowy","%n głosy • Twój głos jest anonimowy"],
    "Your vote is anonymous" : "Twój głos jest anonimowy",
    "You voted for this option" : "Głosowałeś na tę opcję",
    "End poll" : "Zakończ sondę",
    "Change your vote" : "Zmień swój głos",
    "Withdraw vote" : "Wycofaj głos",
    "Results" : "Wyniki",
    "Download as spreadsheet" : "Pobierz jako arkusz kalkulacyjny",
    "Download as CSV" : "Pobierz jako CSV",
    "Voted participants" : "Uczestnicy w głosowaniu",
    "Send a message to \"{roomName}\"" : "Wyślij wiadomość do \"{roomName}\"",
    "Hide list of participants" : "Ukryj listę uczestników",
    "Show list of participants" : "Pokaż listę uczestników",
    "Assistance requested in {roomName}" : "Prośba o pomoc w {roomName}",
    "The message was sent to \"{roomName}\"" : "Wiadomość została wysłana do \"{roomName}\"",
    "Dismiss request for assistance" : "Odrzuć prośbę o pomoc",
    "Send message to room" : "Wyślij wiadomość do pokoju",
    "Back to main room" : "Powrót do głównego pokoju",
    "Back to your room" : "Wróć do swojego pokoju",
    "Message all rooms" : "Wyślij wiadomość do wszystkich pokoi",
    "Start session" : "Rozpocznij sesję",
    "Start a call before you start a breakout room session" : "Rozpocznij rozmowę przed rozpoczęciem sesji w pokoju podgrup",
    "Stop session" : "Zatrzymaj sesję",
    "The message was sent to all breakout rooms" : "Wiadomość została wysłana do wszystkich pokoi podgrup",
    "Send a message to all breakout rooms" : "Wyślij wiadomość do wszystkich pokoi podgrup",
    "Breakout rooms are not started" : "Pokoje podgrup nie są uruchamiane",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Połączenia bez wydajnego zaplecza mogą powodować problemy z łącznością i duże obciążenie urządzeń. {linkstart}Dowiedz się więcej{linkend}",
    "Talk setup incomplete" : "Konfiguracja Talka niekompletna",
    "Disable lobby" : "Wyłącz poczekalnię",
    "Settings for participant \"{user}\"" : "Ustawienia dla uczestnika \"{user}\"",
    "Participant \"{user}\"" : "Uczestnik \"{user}\"",
    "moderator" : "moderator",
    "bot" : "bot",
    "guest" : "gość",
    "Ringing …" : "Dzwoni…",
    "Call rejected" : "Połączenie odrzucone",
    "{time} talking …" : "Rozmawiam {time}…",
    "{time} talking time" : "Czas rozmowy {time}",
    "Raised their hand" : "Podnieśli rękę",
    "Joined with video" : "Połączony z obrazem wideo",
    "Joined via phone" : "Połączony przez telefon",
    "Joined with audio" : "Połączony z dźwiękiem",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Długość tekstu musi być mniejsza lub równa {maxLength} znaków. Twój obecny tekst ma długość {charactersCount} znaków.",
    "Remove group and members" : "Usuń grupę i członków",
    "Remove team and members" : "Usuń zespół i członków",
    "Remove participant" : "Usuń uczestnika",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Czy na pewno chcesz usunąć grupę \"{displayName}\" i jej członków z tej rozmowy?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Czy na pewno chcesz usunąć zespół \"{displayName}\" i jego członków z tej rozmowy?",
    "Do you really want to remove {displayName} from this conversation?" : "Czy na pewno chcesz usunąć {displayName} z tej rozmowy?",
    "Notification was sent to {displayName}" : "Powiadomienie zostało wysłane do {displayName}",
    "Could not send notification to {displayName}" : "Nie udało się wysłać powiadomienia do {displayName}",
    "Permissions granted to {displayName}" : "Uprawnienia przyznane {displayName}",
    "Could not modify permissions for {displayName}" : "Nie udało się zmienić uprawnień dla {displayName}",
    "Permissions removed for {displayName}" : "Usunięto uprawnienia dla {displayName}",
    "Permissions set to default for {displayName}" : "Uprawnienia ustawione na domyślne dla {displayName}",
    "Phone number could not be hung up" : "Nie można rozłączyć numeru telefonu",
    "Phone number could not be put on hold" : "Nie można zawiesić numeru telefonu",
    "Phone number could not be muted" : "Nie można wyciszyć numeru telefonu",
    "Phone number could not be unmuted" : "Nie można wyłączyć wyciszenia numeru telefonu",
    "DTMF message could not be sent" : "Nie można wysłać wiadomości DTMF",
    "Phone number copied to clipboard" : "Numer telefonu skopiowany do schowka",
    "Phone number could not be copied" : "Nie udało się skopiować numeru telefonu",
    "in the lobby" : "w poczekalni",
    "Dial out phone" : "Wybierz telefon",
    "Hang up phone" : "Odłóż słuchawkę",
    "Move back to lobby" : "Powrót do poczekali",
    "Move to conversation" : "Przejdź do rozmowy",
    "Dial-in PIN" : "Kod PIN połączenia telefonicznego",
    "Demote from moderator" : "Degraduj z moderatora",
    "Promote to moderator" : "Awansuj na moderatora",
    "Resend invitation" : "Wyślij ponownie zaproszenie",
    "Send call notification" : "Wyślij powiadomienie o połączeniu",
    "Dial out phone number" : "Wybierz numer telefonu",
    "Resume call for phone number" : "Wznów połączenie dla numeru telefonu",
    "Put phone number on hold" : "Zawieś numer telefonu",
    "Unmute phone number" : "Wyłącz wyciszenie numeru telefonu",
    "Mute phone number" : "Wycisz numer telefonu",
    "Copy phone number" : "Kopiuj numer telefonu",
    "Reset custom permissions" : "Zresetuj uprawnienia niestandardowe",
    "Grant all permissions" : "Przyznaj wszystkie uprawnienia",
    "Remove all permissions" : "Usuń wszystkie uprawnienia",
    "Also ban from this conversation" : "Zbanuj także z tej rozmowy",
    "Internal note (reason to ban)" : "Notatka wewnętrzna (powód zbanowania)",
    "Remove" : "Usuń",
    "Permissions modified for {displayName}" : "Zmieniono uprawnienia dla {displayName}",
    "Add users, groups or teams" : "Dodaj użytkowników, grupy lub zespoły",
    "Add users or groups" : "Dodaj użytkowników lub grupy",
    "Add users or teams" : "Dodaj użytkowników lub zespoły",
    "Add users" : "Dodaj użytkowników",
    "Add groups or teams" : "Dodaj grupy lub zespoły",
    "Add groups" : "Dodaj grupy",
    "Add teams" : "Dodaj zespoły",
    "Add other sources" : "Dodaj inne źródła",
    "Add emails" : "Dodaj e-maile",
    "Integrations" : "Integracje",
    "Add federated users" : "Dodaj użytkowników federacyjnych",
    "Searching …" : "Wyszukiwanie…",
    "Search for more users" : "Wyszukaj więcej użytkowników",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Możesz wyszukiwać i dodawać uczestników po nazwisku, adresie e-mail lub ID Chmury Federacyjnej",
    "Search or add participants" : "Wyszukaj lub dodaj uczestników",
    "Invitation was sent to {actorId}" : "Zaproszenie zostało wysłane do {actorId}",
    "An error occurred while adding the participants" : "Wystąpił błąd podczas dodawania uczestników",
    "A new group conversation with selected participant will be created" : "Zostanie utworzona nowa rozmowa grupowa z wybranym uczestnikiem",
    "Participants" : "Uczestnicy",
    "Pinned by a deleted user" : "Przypięte przez usuniętego użytkownika",
    "Participants ({count})" : "Uczestnicy ({count})",
    "Open chat" : "Otwórz rozmowę",
    "You have new unread messages in the chat." : "Masz nowe nieprzeczytane wiadomości na czacie.",
    "You have been mentioned in the chat." : "Zostałeś wspomniany na czacie.",
    "Search messages" : "Szukaj wiadomości",
    "Chat" : "Rozmowa",
    "Details" : "Szczegóły",
    "Shared items" : "Udostępnione elementy",
    "Search in {name}" : "Szukaj w {name}",
    "Threads in {name}" : "Wątki w {name}",
    "{actor} in {conversation}" : "{actor} w {conversation}",
    "Search messages …" : "Szukaj wiadomości…",
    "Search options" : "Opcje wyszukiwania",
    "From User" : "Od użytkownika",
    "Since" : "Od",
    "Until" : "Dopóki",
    "No results found" : "Nie znaleziono wyników",
    "Load more results" : "Wczytaj więcej wyników",
    "Recent threads" : "Ostatnie wątki",
    "Projects" : "Projekty",
    "No shared items" : "Brak udostępnionych elementów",
    "Thread notifications" : "Powiadomienia wątków",
    "Thread actions" : "Akcje wątków",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Link do rozmowy",
    "No open conversations found" : "Nie znaleziono otwartych rozmów",
    "Either there are no open conversations or you joined all of them." : "Albo nie ma żadnych otwartych rozmów, albo dołączyłeś do wszystkich.",
    "Check spelling or use complete words." : "Sprawdź pisownię lub użyj pełnych słów.",
    "Search conversations or users" : "Szukaj rozmów lub użytkowników",
    "Select conversation" : "Wybierz rozmowę",
    "Number length is not valid" : "Długość numeru jest nieprawidłowa",
    "Region code is not valid" : "Kod regionu jest nieprawidłowy",
    "Number length is too short" : "Długość numeru jest za krótka",
    "Number length is too long" : "Długość numeru jest za długa",
    "Number is not valid" : "Numer jest nieprawidłowy",
    "Phone numbers" : "Numery telefonu",
    "Display name: {name}" : "Wyświetlana nazwa: {name}",
    "Edit display name" : "Edytuj wyświetlaną nazwę",
    "Display name (required)" : "Wymagana nazwa wyświetlana",
    "Save name" : "Zapisz nazwę",
    "I picked message bubbles" : "Wybrałem dymki wiadomości",
    "I picked the list style" : "Wybrałem styl listy",
    "Error while setting personal setting" : "Błąd podczas ustawiania ustawień osobistych",
    "Error while saving sounds setting" : "Błąd podczas zapisywania ustawień dźwięków",
    "Compact conversations list" : "Kompaktowa lista rozmów",
    "Chat appearance" : "Wygląd czatu",
    "Messages list" : "Lista wiadomości",
    "Message bubbles" : "Dymki wiadomości",
    "Play sounds when participants join or leave a call" : "Odtwarzaj dźwięki, gdy uczestnicy dołączają lub opuszczają połączenie",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Obecnie niedostępne na iPhonie i iPadzie z powodu ograniczeń technicznych narzuconych przez producenta",
    "Notification settings" : "Ustawienia powiadomień",
    "Sounds for chat and call notifications" : "Dźwięki powiadomień czatu i połączeń",
    "Invalid language ({languageId})" : "Nieprawidłowy język ({languageId})",
    "Default language" : "Domyślny język",
    "Default language ({languageName})" : "Język domyślny ({languageName})",
    "Error when trying to load the available live translation languages" : "Błąd podczas próby wczytania dostępnych języków tłumaczenia na żywo",
    "Error when trying to set live translation language" : "Błąd podczas próby ustawienia języka tłumaczenia na żywo",
    "Set language used to show the transcriptions" : "Ustaw język używany do wyświetlania transkrypcji",
    "Select location for attachments" : "Wybierz lokalizację dla załączników",
    "Error while setting attachment folder" : "Błąd podczas ustawiania katalogu dla załącznika",
    "Error while setting read status privacy" : "Błąd podczas ustawiania prywatności statusu odczytu",
    "Error while setting typing status privacy" : "Błąd podczas ustawiania prywatności statusu pisania",
    "Error while setting default media state" : "Błąd podczas ustawiania domyślnego stanu multimediów",
    "Turn camera and microphone off by default" : "Domyślnie wyłącz kamerę i mikrofon",
    "Blur camera background by default" : "Domyślnie rozmyj tło kamery",
    "Skip device preview before joining a call" : "Pomiń podgląd urządzeń przed dołączeniem do rozmowy",
    "Camera will be turned off when joining. Always shown if recording consent is required." : "Kamera zostanie wyłączona podczas dołączania. Zawsze pokazuj, jeśli wymagana jest zgoda na nagrywanie.",
    "Appearance & Sounds" : "Wygląd i dźwięki",
    "Privacy" : "Prywatność",
    "Send read receipts" : "Wysyłaj potwierdzenia odczytu",
    "When off, all read statuses will be hidden" : "Gdy wyłączone, wszystkie statusy odczytu będą ukryte",
    "Share typing status" : "Udostępniaj status pisania",
    "When off, all typing indicators will be hidden" : "Gdy wyłączone, wszystkie wskaźniki pisania będą ukryte",
    "Attachments folder" : "Katalog z załącznikami",
    "Toggle full screen" : "Przełącz tryb pełnoekranowy",
    "Return to Home screen" : "Wróć do ekranu głównego",
    "Search" : "Szukaj",
    "Shortcuts while in a chat" : "Skróty klawiaturowe w czacie",
    "Focus the chat input" : "Skoncentruj się na rozmowie",
    "Unfocus the chat input to use shortcuts" : "Zakończ koncentrację na rozmowie, aby używać skrótów",
    "Edit your last message" : "Edytuj swoją ostatnią wiadomość",
    "Shortcuts while in a call" : "Skróty podczas połączenia",
    "Camera on and off" : "Włącz i wyłącz kamerę",
    "Microphone on and off" : "Włącz i wyłącz mikrofon",
    "Raise or lower hand" : "Podnieś lub opuść rękę",
    "Push to talk or push to mute" : "Naciśnij, aby mówić lub naciśnij, aby wyciszyć",
    "Zoom-in / zoom-out a screen share" : "Powiększanie/pomniejszanie udostępnionego ekranu",
    "Mouse wheel" : "Kółko myszy",
    "Start call silently" : "Rozpocznij połączenie po cichu",
    "Start call" : "Rozpocznij połączenie",
    "End call" : "Zakończ połączenie",
    "The server was updated, you cannot start or join a call." : "Serwer został zaktualizowany, nie możesz rozpocząć ani dołączyć do rozmowy",
    "This call has just ended" : "To połączenie właśnie się zakończyło",
    "You will be able to join the call only after a moderator starts it." : "Do rozmowy będziesz mógł dołączyć dopiero jako moderator.",
    "End call for everyone" : "Zakończ połączenie dla wszystkich",
    "Starting the recording" : "Rozpoczęcie nagrywania",
    "Recording" : "Nagranie",
    "The call has been running for one hour." : "Połączenie trwa od godziny.",
    "Cancel recording start" : "Anuluj rozpoczęcie nagrywania",
    "Stop recording" : "Zatrzymaj nagrywanie",
    "Raise hand" : "Podnieść rękę",
    "Raise hand (R)" : "Podnieś rękę (R)",
    "Lower hand" : "Opuścić rękę",
    "Lower hand (R)" : "Opuść rękę (R)",
    "Send a reaction" : "Wyślij reakcję",
    "React with {reaction}" : "Reakcja {reaction}",
    "All tasks done!" : "Wszystkie zadania wykonane!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} z %n zadania","{done} z %n zadań","{done} z %n zadań","{done} z %n zadań"],
    "Add participants to this call" : "Dodaj uczestników do tej rozmowy",
    "_%n participant in call_::_%n participants in call_" : ["%n uczestnik rozmowy","%n uczestników rozmowy","%n uczestników rozmowy","%n uczestników rozmowy"],
    "Scheduled messages" : "Zaplanowane wiadomości",
    "You are not allowed to enable screensharing" : "Nie możesz włączyć udostępniania ekranu",
    "No screensharing" : "Brak udostępniania ekranu",
    "Screensharing options" : "Opcje udostępniania ekranu",
    "Enable screensharing" : "Włącz udostępnianie ekranu",
    "Bad sent video and screen quality." : "Zła jakość wysyłanego obrazu wideo i ekranu.",
    "Bad sent screen quality." : "Zła jakość wysyłanego ekranu.",
    "Bad sent video quality." : "Zła jakość wysyłanego obrazu wideo.",
    "Bad sent audio, video and screen quality." : "Zła jakość wysyłanego dźwięku, obrazu wideo i ekranu.",
    "Bad sent audio and screen quality." : "Zła jakość wysyłanego dźwięku i ekranu.",
    "Bad sent audio and video quality." : "Zła jakość wysyłanego dźwięku i obrazu wideo.",
    "Bad sent audio quality." : "Zła jakość wysyłanego dźwięku.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Twoje połączenie internetowe lub komputer jest znacznie obciążony i inni uczestnicy mogą nie widzieć Twojego ekranu. Aby poprawić sytuację, spróbuj wyłączyć rozmycie tła lub obraz wideo podczas udostępniania ekranu.",
    "Disable background blur" : "Wyłącz rozmycie tła",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Twoje połączenie internetowe lub komputer jest znacznie obciążony i inni uczestnicy mogą nie widzieć Twojego ekranu. Aby poprawić sytuację, spróbuj wyłączyć obraz wideo podczas udostępniania ekranu.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Twoje połączenie internetowe lub komputer jest znacznie obciążony. Inni uczestnicy mogą nie widzieć Twojego ekranu.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Twoje połączenie internetowe lub komputer jest znacznie obciążony. Inni uczestnicy mogą Ciebie nie widzieć.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Twoje połączenie internetowe lub komputer jest znacznie obciążony i inni uczestnicy mogą nie być w stanie Ciebie zrozumieć i zobaczyć. Aby poprawić sytuację, spróbuj wyłączyć rozmycie tła lub obraz wideo podczas udostępniania ekranu.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Twoje połączenie internetowe lub komputer jest znacznie obciążony. Inni uczestnicy mogą Ciebie nie zrozumieć i nie widzieć. Aby poprawić sytuację, spróbuj wyłączyć obraz wideo podczas udostępniania ekranu.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Twoje połączenie internetowe lub komputer jest znacznie obciążony i inni uczestnicy mogą nie być w stanie Ciebie zrozumieć i zobaczyć Twojego ekranu. Aby poprawić sytuację, spróbuj wyłączyć udostępnianie ekranu.",
    "Disable screenshare" : "Wyłącz udostępnianie ekranu",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Twoje połączenie internetowe lub komputer jest znacznie obciążony i inni uczestnicy mogą nie być w stanie Ciebie zrozumieć i zobaczyć. Aby poprawić sytuację, spróbuj wyłączyć rozmycie tła lub obraz wideo.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Twoje połączenie internetowe lub komputer jest znacznie obciążony. Inni uczestnicy mogą Ciebie nie zrozumieć i nie widzieć. Aby poprawić sytuację, spróbuj wyłączyć obraz wideo.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Twoje połączenie internetowe lub komputer jest znacznie obciążony. Inni uczestnicy mogą Ciebie nie zrozumieć.",
    "Screen sharing is not supported by your browser." : "Udostępnianie ekranu nie jest obsługiwane przez Twoją przeglądarkę.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Udostępnianie ekranu wymaga załadowania strony za pomocą protokołu HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Udostępnianie ekranu wymaga załadowania strony za pomocą protokołu HTTPS.",
    "An error occurred while starting screensharing." : "Wystąpił błąd podczas uruchamiania udostępniania ekranu.",
    "Select virtual background" : "Wybierz wirtualne tło",
    "Show your screen" : "Pokaż swój ekran",
    "Stop screensharing" : "Zatrzymaj udostępnianie ekranu",
    "Mute others" : "Wycisz innych",
    "Start recording" : "Rozpocznij nagrywanie",
    "Set up breakout rooms" : "Skonfiguruj pokoje podgrup",
    "Download attendance list" : "Pobierz listę obecności",
    "Open Calendar" : "Otwórz Kalendarz",
    "Remove participant {name}" : "Usuń uczestnika {name}",
    "Would you like to delete this conversation?" : "Czy chcesz usunąć tą rozmowę?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Ta rozmowa zostanie automatycznie usunięta dla wszystkich po %n dniu braku aktywności","Ta rozmowa zostanie automatycznie usunięta dla wszystkich po %n dniach braku aktywności","Ta rozmowa zostanie automatycznie usunięta dla wszystkich po %n dniach braku aktywności","Ta rozmowa zostanie automatycznie usunięta dla wszystkich po %n dniach braku aktywności"],
    "Are you sure you want to delete this conversation?" : "Czy na pewno chcesz usunąć tę rozmowę?",
    "Delete now" : "Usuń teraz",
    "Keep" : "Pozostaw",
    "Open dialpad" : "Otwórz klawiaturę numeryczną",
    "Select a region" : "Wybierz region",
    "Local time: {time}" : "Czas lokalny: {time}",
    "Scheduled {datetime}" : "Zaplanowano {datetime}",
    "Scheduled for {datetime}" : "Zaplanowano na {datetime}",
    "Search …" : "Szukaj…",
    "Message without mention" : "Wiadomość bez wzmianki",
    "Mention myself" : "Wspomnij o sobie",
    "Mention everyone" : "Wspomnij wszystkich",
    "Select a conversation" : "Wybierz rozmowę",
    "Select a mode" : "Wybierz tryb",
    "You do not have permissions to access this conversation." : "Nie masz uprawnień dostępu do tej rozmowy.",
    "Join a different conversation or start a new one." : "Dołącz do innej rozmowy lub rozpocznij nową.",
    "The conversation does not exist" : "Rozmowa nie istnieje",
    "Join a conversation or start a new one!" : "Dołącz do rozmowy lub rozpocznij nową!",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Ta rozmowa została otwarta w innej karcie. Bieżąca wersja serwera nie obsługuje otwierania rozmowy w wielu kartach",
    "Creating and joining a conversation with \"{userid}\"" : "Tworzenie i dołączanie do rozmowy z „{userid}”",
    "Join a conversation or start a new one" : "Dołącz do rozmowy lub rozpocznij nową",
    "Error while joining the conversation" : "Błąd podczas dołączania do rozmowy",
    "Another user" : "Inny użytkownik",
    "Hey! Are you using the list style or message bubbles?" : "Hej! Czy używasz stylu listy czy dymków wiadomości?",
    "Nextcloud URL" : "Adres URL Nextcloud",
    "Nextcloud user" : "Użytkownik Nextcloud",
    "User password" : "Hasło użytkownika",
    "Talk conversation" : "Rozmowa Talk",
    "Skip TLS verification" : "Pomiń weryfikację TLS",
    "Matrix server URL" : "Adres URL serwera Matrix",
    "User" : "Użytkownik",
    "Matrix channel" : "Kanał Matrix",
    "Mattermost server URL" : "Adres URL serwera Mattermost",
    "Mattermost user" : "Użytkownik Mattermost",
    "Team name" : "Nazwa zespołu",
    "Channel name" : "Nazwa kanału",
    "Rocket.Chat server URL" : "Adres URL serwera Rocket.Chat",
    "User name or email address" : "Nazwa użytkownika lub adres e-mail",
    "Rocket.Chat channel" : "Kanał Rocket.Chat",
    "Zulip server URL" : "Adres URL serwera Zulip",
    "Bot user name" : "Nazwa użytkownika bota",
    "Bot API key" : "Klucz API bota",
    "Zulip channel" : "Kanał Zulip",
    "API token" : "Token API",
    "Slack channel" : "Kanał Slack",
    "Server ID or name" : "ID lub nazwa serwera",
    "Channel ID (prefixed with \"ID:\") or name" : "Identyfikator kanału (poprzedzony „ID:”) lub nazwa",
    "Channel" : "Kanał",
    "Login" : "Login",
    "Chat ID" : "ID rozmowy",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "Adres URL serwera IRC (np. chat.freenode.net:6667)",
    "Nickname" : "Pseudonim",
    "Connection password" : "Hasło połączenia",
    "IRC channel" : "Kanał IRC",
    "Channel password" : "Hasło kanału",
    "NickServ nickname" : "Nazwa NickServ",
    "NickServ password" : "Hasło NickServ",
    "Use TLS" : "Użyj TLS",
    "Use SASL" : "Użyj SASL",
    "Tenant ID" : "ID Tenant",
    "Client ID" : "ID klienta",
    "Team ID" : "ID Team",
    "Thread ID" : "ID Thread",
    "XMPP/Jabber server URL" : "Adres URL serwera XMPP/Jabber",
    "MUC server URL" : "Adres URL serwera MUC",
    "Jabber ID" : "ID Jabber",
    "Pinned messages" : "Przypięte wiadomości",
    "Media" : "Multimedia",
    "Polls" : "Sondy",
    "Deck cards" : "Karty tablicy",
    "Voice messages" : "Wiadomości głosowe",
    "Locations" : "Lokalizacje",
    "Call recordings" : "Nagrania rozmów",
    "Audio" : "Audio",
    "Show all pinned messages" : "Pokaż wszystkie przypięte wiadomości",
    "Show all media" : "Pokaż wszystkie multimedia",
    "Show all files" : "Pokaż wszystkie pliki",
    "Show all polls" : "Pokaż wszystkie sondy",
    "Show all deck cards" : "Pokaż wszystkie karty tablicy",
    "Show all voice messages" : "Pokaż wszystkie wiadomości głosowe",
    "Show all locations" : "Pokaż wszystkie lokalizacje",
    "Show all call recordings" : "Pokaż wszystkie nagrania rozmów",
    "Show all audio" : "Pokaż wszystkie audio",
    "Show all other" : "Pokaż wszystkie inne",
    "Follow conversation settings" : "Śledź ustawienia rozmowy",
    "Group" : "Grupa",
    "Team" : "Zespół",
    "You reconnected to the call" : "Ponownie połączyłeś się z połączeniem",
    "{actor} reconnected to the call" : "{actor} ponownie połączył się z połączeniem",
    "You added {user0} and {user1}" : "Dodałeś {user0} i {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Dodałeś {user0}, {user1} i %n uczestnika","Dodałeś {user0}, {user1} i %n uczestników","Dodałeś {user0}, {user1} i %n uczestników","Dodałeś {user0}, {user1} i %n uczestników"],
    "An administrator added you and {user0}" : "Administrator dodał Ciebie i {user0}",
    "{actor} added you and {user0}" : "{actor} dodał Ciebie i {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Administrator dodał Ciebie, {user0} i %n uczestnika","Administrator dodał Ciebie, {user0} i %n uczestników","Administrator dodał Ciebie, {user0} i %n uczestników","Administrator dodał Ciebie, {user0} i %n uczestników"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} dodał Ciebie, {user0} i %n uczestnika","{actor} dodał Ciebie, {user0} i %n uczestników","{actor} dodał Ciebie, {user0} i %n uczestników","{actor} dodał Ciebie, {user0} i %n uczestników"],
    "An administrator added {user0} and {user1}" : "Administrator dodał {user0} and {user1}",
    "{actor} added {user0} and {user1}" : "{actor} dodał {user0} i {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Administrator dodał {user0}, {user1} i %n uczestnika","Administrator dodał {user0}, {user1} i %n uczestników","Administrator dodał {user0}, {user1} i %n uczestników","Administrator dodał {user0}, {user1} i %n uczestników"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} dodał {user0}, {user1} i %n uczestnika","{actor} dodał {user0}, {user1} i %n uczestników","{actor} dodał {user0}, {user1} i %n uczestników","{actor} dodał {user0}, {user1} i %n uczestników"],
    "You removed {user0} and {user1}" : "Usunąłeś {user0} i {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Usunąłeś {user0}, {user1} i %n uczestnika","Usunąłeś {user0}, {user1} i %n uczestników","Usunąłeś {user0}, {user1} i %n uczestników","Usunąłeś {user0}, {user1} i %n uczestników"],
    "An administrator removed you and {user0}" : "Administrator usunął Cię i {user0}",
    "{actor} removed you and {user0}" : "{actor} usunął Ciebie i {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Administrator usunął Ciebie, {user0} i %n uczestnika","Administrator usunął Ciebie, {user0} i %n uczestników","Administrator usunął Ciebie, {user0} i %n uczestników","Administrator usunął Ciebie, {user0} i %n uczestników"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} usunął Ciebie, {user0} i %n uczestnika","{actor} usunął Ciebie, {user0} i %n uczestników","{actor} usunął Ciebie, {user0} i %n uczestników","{actor} usunął Ciebie, {user0} i %n uczestników"],
    "An administrator removed {user0} and {user1}" : "Administrator usunął {user0} i {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} usunął {user0} i {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Administrator usunął {user0}, {user1} i %n innego uczestnika","Administrator usunął {user0}, {user1} i %n innych uczestników","Administrator usunął {user0}, {user1} i %n innych uczestników","Administrator usunął {user0}, {user1} i %n innych uczestników"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} usuną {user0}, {user1} i %n innego uczestnika","{actor} usuną {user0}, {user1} i %n innych uczestników","{actor} usuną {user0}, {user1} i %n innych uczestników","{actor} usuną {user0}, {user1} i %n innych uczestników"],
    "You and {user0} joined the call" : "Ty i {user0} dołączyliście do połączenia",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Ty, {user0} i %n uczestnik dołączył do połączenia","Ty, {user0} i %n uczestników dołączyło do połączenia","Ty, {user0} i %n uczestników dołączyło do połączenia","Ty, {user0} i %n uczestników dołączyło do połączenia"],
    "{user0} and {user1} joined the call" : "{user0} i {user1} dołączyli do połączenia",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} i %n uczestnik dołączył do połączenia","{user0}, {user1} i %n uczestników dołączyło do połączenia","{user0}, {user1} i %n uczestników dołączyło do połączenia","{user0}, {user1} i %n uczestników dołączyło do połączenia"],
    "You and {user0} left the call" : "Ty i {user0} opuściliście połączenie",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Ty, {user0} i %n uczestnik opuścił połączenie","Ty, {user0} i %n uczestników opuściło połączenie","Ty, {user0} i %n uczestników opuściło połączenie","Ty, {user0} i %n uczestników opuściło połączenie"],
    "{user0} and {user1} left the call" : "{user0} i {user1} opuścili połączenie",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} i %n uczestnik opuścił połączenie","{user0}, {user1} i %n uczestników opuściło połączenie","{user0}, {user1} i %n uczestników opuściło połączenie","{user0}, {user1} i %n uczestników opuściło połączenie"],
    "You promoted {user0} and {user1} to moderators" : "Awansowałeś {user0} i {user1} na moderatorów",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Awansowałeś użytkowników na moderatorów: {user0}, {user1} i %n uczestnika","Awansowałeś użytkowników na moderatorów: {user0}, {user1} i %n uczestników","Awansowałeś użytkowników na moderatorów: {user0}, {user1} i %n uczestników","Awansowałeś użytkowników na moderatorów: {user0}, {user1} i %n uczestników"],
    "An administrator promoted you and {user0} to moderators" : "Administrator awansował Ciebie i {user0} na moderatorów",
    "{actor} promoted you and {user0} to moderators" : "{actor} awansował Ciebie i {user0} na moderatorów",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Administrator awansował Ciebie, {user0} i %n uczestnika na moderatorów","Administrator awansował Ciebie, {user0} i %n uczestników na moderatorów","Administrator awansował Ciebie, {user0} i %n uczestników na moderatorów","Administrator awansował Ciebie, {user0} i %n uczestników na moderatorów"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} awansował Ciebie, {user0} i %n uczestnika na moderatorów","{actor} awansował Ciebie, {user0} i %n uczestników na moderatorów","{actor} awansował Ciebie, {user0} i %n uczestników na moderatorów","{actor} awansował Ciebie, {user0} i %n uczestników na moderatorów"],
    "An administrator promoted {user0} and {user1} to moderators" : "Administrator awansował {user0} i {user1} na moderatorów",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} awansował {user0} i {user1} na moderatorów",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Administrator awansował {user0}, {user1} i %n uczestnika na moderatorów","Administrator awansował {user0}, {user1} i %n uczestników na moderatorów","Administrator awansował {user0}, {user1} i %n uczestników na moderatorów","Administrator awansował {user0}, {user1} i %n uczestników na moderatorów"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} awansował {user0}, {user1} i %n uczestnika na moderatorów","{actor} awansował {user0}, {user1} i %n uczestników na moderatorów","{actor} awansował {user0}, {user1} i %n uczestników na moderatorów","{actor} awansował {user0}, {user1} i %n uczestników na moderatorów"],
    "You demoted {user0} and {user1} from moderators" : "Zdegradowałeś {user0} i {user1} z moderatorów",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Zdegradowałeś {user0}, {user1} i %n innego uczestnika z moderatorów","Zdegradowałeś {user0}, {user1} i %n innych uczestników z moderatorów","Zdegradowałeś {user0}, {user1} i %n innych uczestników z moderatorów","Zdegradowałeś {user0}, {user1} i %n innych uczestników z moderatorów"],
    "An administrator demoted you and {user0} from moderators" : "Administrator zdegradował Ciebie i użytkownika {user0} z moderatorów",
    "{actor} demoted you and {user0} from moderators" : "{actor} zdegradował Ciebie i {user0} z moderatorów",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Administrator zdegradował Ciebie, {user0} i %n innego uczestnika z moderatorów","Administrator zdegradował Ciebie, {user0} i %n innych uczestników z moderatorów","Administrator zdegradował Ciebie, {user0} i %n innych uczestników z moderatorów","Administrator zdegradował Ciebie, {user0} i %n innych uczestników z moderatorów"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} zdegradował Ciebie, {user0} i %n innego uczestnika z moderatorów","{actor} zdegradował Ciebie, {user0} i %n innych uczestników z moderatorów","{actor} zdegradował Ciebie, {user0} i %n innych uczestników z moderatorów","{actor} zdegradował Ciebie, {user0} i %n innych uczestników z moderatorów"],
    "An administrator demoted {user0} and {user1} from moderators" : "Administrator zdegradował użytkowników {user0} i {user1} z moderatorów",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} zdegradował użytkowników {user0} i {user1} z moderatorów",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Administrator zdegradował {user0}, {user1} i %n uczestnika z moderatorów","Administrator zdegradował {user0}, {user1} i %n uczestników z moderatorów","Administrator zdegradował {user0}, {user1} i %n uczestników z moderatorów","Administrator zdegradował {user0}, {user1} i %n uczestników z moderatorów"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} zdegradował {user0}, {user1} i %n innego uczestnika z moderatorów","{actor} zdegradował {user0}, {user1} i %n innych uczestników z moderatorów","{actor} zdegradował {user0}, {user1} i %n innych uczestników z moderatorów","{actor} zdegradował {user0}, {user1} i %n innych uczestników z moderatorów"],
    "You:" : "Ty:",
    "You: {lastMessage}" : "Ty: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "Serwer został zaktualizowany",
    "(edited by you)" : "(edytowane przez Ciebie)",
    "(edited by a deleted user)" : "(edytowane przez usuniętego użytkownika)",
    "(edited by {moderator})" : "(edytowane przez {moderator})",
    "The recording failed. Please contact your administrator." : "Nagrywanie nie powiodło się. Skontaktuj się z administratorem.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Próbujesz dołączyć do rozmowy, mając aktywną sesję w innym oknie lub urządzeniu. Obecnie ta sesja nie jest jeszcze obsługiwana przez Nextcloud Talk. Co chcesz zrobić?",
    "Leave this page" : "Opuść stronę",
    "Join here" : "Dołącz tutaj",
    "Deck card has been posted to {conversation}" : "Tablica została opublikowana w {conversation}",
    "An error occurred while posting deck card to conversation" : "Wystąpił błąd podczas dodawania karty do rozmowy",
    "Post to a conversation" : "Opublikuj w rozmowie",
    "Post to conversation" : "Opublikuj w rozmowie",
    "Location has been posted to {conversation}" : "Lokalizacja została wysłana do {conversation}",
    "An error occurred while posting location to conversation" : "Wystąpił błąd podczas publikowania lokalizacji w rozmowie",
    "Share to a conversation" : "Udostępnij w rozmowie",
    "Share to conversation" : "Udostępnij w rozmowie",
    "In conversation" : "W rozmowie",
    "Search in conversation: {conversation}" : "Szukaj w rozmowie: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Twoje żądania są obecnie ograniczane ze względu na ochronę przed atakami typu brute force",
    "Error while clearing conversation history" : "Błąd podczas czyszczenia historii rozmowy",
    "Error occurred while allowing guests" : "Wystąpił błąd podczas zezwalania gościom",
    "Error occurred while disallowing guests" : "Wystąpił błąd podczas blokowania gościom",
    "Error occurred when restricting the conversation to moderator" : "Wystąpił błąd podczas ograniczania rozmowy do moderatora",
    "Error occurred when opening the conversation to everyone" : "Wystąpił błąd podczas otwierania rozmowy dla wszystkich",
    "Conversation password has been saved" : "Hasło do rozmowy zostało zapisane",
    "Conversation password has been removed" : "Hasło do rozmowy zostało usunięte",
    "Error occurred while saving conversation password" : "Wystąpił błąd podczas zapisywania hasła do rozmowy",
    "Call recording is starting." : "Rozpoczęło się nagrywanie rozmowy.",
    "Call recording stopped while starting." : "Nagrywanie rozmowy zostało zatrzymane podczas uruchamiania.",
    "Call recording stopped. You will be notified once the recording is available." : "Nagrywanie rozmowy zostało zatrzymane. Otrzymasz powiadomienie, gdy nagranie będzie dostępne.",
    "Conversation picture set" : "Zestaw obrazów rozmowy",
    "Conversation picture deleted" : "Obraz rozmowy został usunięty",
    "Could not delete the conversation picture" : "Nie można usunąć obrazu rozmowy",
    "Could not remove the automatic expiration" : "Nie udało się usunąć automatycznego wygaśnięcia",
    "Could not post message: {errorMessage}" : "Nie można wysłać wiadomości: {errorMessage}",
    "Participant is banned successfully" : "Uczestnik został pomyślnie zbanowany",
    "Error while banning the participant" : "Błąd podczas blokowania uczestnika",
    "An error occurred while fetching the participants" : "Wystąpił błąd podczas pobierania uczestników",
    "Could not send invitation to {actorId}" : "Nie można wysłać zaproszenia do {actorId}",
    "Invitations sent" : "Wysłano zaproszenia",
    "Error occurred when sending invitations" : "Wystąpił błąd podczas wysyłania zaproszeń",
    "Failed to join the conversation." : "Nie udało się dołączyć do rozmowy.",
    "An error occurred while creating breakout rooms" : "Podczas tworzenia pokoi podgrup wystąpił błąd",
    "An error occurred while re-ordering the attendees" : "Podczas zmiany kolejności uczestników wystąpił błąd",
    "An error occurred while deleting breakout rooms" : "Podczas usuwania pokoi podgrup wystąpił błąd",
    "An error occurred while starting breakout rooms" : "Podczas uruchamiania pokoi podgrup wystąpił błąd",
    "An error occurred while stopping breakout rooms" : "Podczas zatrzymywania pokoi podgrup wystąpił błąd",
    "An error occurred while sending a message to the breakout rooms" : "Podczas wysyłania wiadomości do pokoi podgrup wystąpił błąd",
    "An error occurred while requesting assistance" : "Wystąpił błąd podczas prośby o pomoc",
    "An error occurred while resetting the request for assistance" : "Wystąpił błąd podczas resetowania prośby o pomoc",
    "An error occurred while joining breakout room" : "Podczas dołączania do podgrupy wystąpił błąd",
    "Failed to rename the thread" : "Nieudana próba zmiany nazwy wątku",
    "Error renaming tag" : "Błąd podczas zmiany nazwy tagu",
    "Error deleting tag" : "Błąd podczas usuwania tagu",
    "Error reordering tags" : "Błąd podczas zmiany kolejności tagów",
    "Error fetching upcoming events" : "Błąd podczas pobierania nadchodzących wydarzeń",
    "Error fetching upcoming reminders" : "Błąd podczas pobierania nadchodzących przypomnień",
    "An error occurred while accepting an invitation" : "Wystąpił błąd podczas akceptowania zaproszenia",
    "An error occurred while rejecting an invitation" : "Wystąpił błąd podczas odrzucania zaproszenia",
    "{guest} (guest)" : "{guest} (gość)",
    "Poll draft has been saved" : "Wersja robocza ankiety została zapisana",
    "An error occurred while saving the draft" : "Wystąpił błąd podczas zapisywania wersji roboczej",
    "An error occurred while submitting your vote" : "Wystąpił błąd podczas wysyłania głosu",
    "An error occurred while ending the poll" : "Wystąpił błąd podczas zamykania sondy",
    "An error occurred while deleting the poll draft" : "Wystąpił błąd podczas usuwania wersji roboczej ankiety",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Sonda \"{name}\" została utworzona przez {user}. Kliknij, aby zagłosować",
    "Failed to add reaction" : "Nie udało się dodać reakcji",
    "Failed to remove reaction" : "Nie udało się usunąć reakcji",
    "The server is in maintenance mode." : "Serwer jest w trybie konserwacji",
    "Federated server was updated." : "Zaktualizowano serwer federacyjny",
    "Error while uploading file \"{fileName}\"" : "Błąd podczas wysyłania pliku \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Za mało wolnego miejsca, aby wysłać plik \"{fileName}\"",
    "You are not allowed to share files" : "Nie możesz udostępniać plików",
    "Error while sharing file" : "Błąd podczas udostępniania pliku",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Używana przeglądarka nie obsługuje w pełni Nextcloud Talk. Użyj najnowszej wersji Mozilla Firefox, Microsoft Edge, Google Chrome, Opera lub Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n godzina","%n godziny","%n godzin","%n godzin"],
    "_%n day_::_%n days_" : ["%n dzień","%n dni","%n dni","%n dni"],
    "_%n week_::_%n weeks_" : ["%n tydzień","%n tygodnie","%n tygodni","%n tygodni"],
    "_In %n hour_::_In %n hours_" : ["Za %n godzinę","Za %n godziny","Za %n godzin","Za %n godzin"],
    "_%n minute _::_%n minutes_" : ["%n minutę","%n minuty","%n minut","%n minut"],
    "In {hours} and {minutes}" : "Za {hours} i {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Za %n minutę","Za %n minuty","Za %n minut","Za %n minut"],
    "Later today – {timeLocale}" : "Później dzisiaj – {timeLocale}",
    "Set time for later today" : "Ustaw czas na później dziś",
    "Tomorrow – {timeLocale}" : "Jutro – {timeLocale}",
    "Set time for tomorrow" : "Ustaw czas na jutro",
    "This weekend – {timeLocale}" : "W ten weekend – {timeLocale}",
    "Set time for this weekend" : "Ustaw czas na ten weekend",
    "Next week – {timeLocale}" : "Następny tydzień – {timeLocale}",
    "Set time for next week" : "Ustaw czas na przyszły tydzień",
    "Message link copied to clipboard" : "Link wiadomości został skopiowany do schowka",
    "Conversation link copied to clipboard" : "Link do rozmowy skopiowany do schowka",
    "The link could not be copied" : "Nie można skopiować linku",
    "Error while parsing a PROPFIND error" : "Wystąpił błąd podczas analizowania błędu PROPFIND",
    "Sending signaling message has failed" : "Wysłanie wiadomości sygnalizacyjnej nie powiodło się",
    "Lost connection to signaling server. Trying to reconnect." : "Utracono połączenie z serwerem sygnalizacyjnym. Ponowna próba połączenia się.",
    "Lost connection to signaling server." : "Utracono połączenie z serwerem sygnalizacyjnym.",
    "Connecting is taking longer than expected …" : "Łączenie trwa dłużej niż oczekiwano…",
    "Failed to connect. Retrying …" : "Nie udało się połączyć. Ponawianie…",
    "Failed to connect. The signaling server may be set up incorrectly" : "Nie udało się połączyć. Serwer sygnalizacyjny może być nieprawidłowo skonfigurowany",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Skonfigurowany serwer sygnalizacyjny wymaga aktualizacji, aby był kompatybilny z tą wersją Talka. Skontaktuj się z administracją.",
    "Please restart the app." : "Uruchom ponownie aplikację.",
    "Please reload the page." : "Przeładuj stronę.",
    "Please try to restart the app." : "Spróbuj ponownie uruchomić aplikację.",
    "Please try to reload the page." : "Spróbuj ponownie wczytać stronę.",
    "Do not disturb" : "Nie przeszkadzać",
    "Away" : "Bezczynny",
    "Microphone {number}" : "Mikrofon {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Głośnik {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Wygląda na to, że jesteś wyciszony podczas rozmowy. Wyłącz wyciszenie, aby inni mogli Ciebie usłyszeć.",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Nie można nawiązać połączenia z żadnym uczestnikiem. Serwer TURN może być potrzebny w Twoim przypadku. Poproś administratora o skonfigurowanie go zgodnie z {linkstart}tą dokumentacją{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Trwa to dłużej niż oczekiwano. Czy uprawnienia do mediów zostały już przyznane (lub odrzucone)? Jeśli tak, to uruchom ponownie przeglądarkę, ponieważ dźwięk i obraz wideo nie działają poprawnie",
    "Access to microphone & camera is only possible with HTTPS" : "Dostęp do mikrofonu i kamery jest możliwy tylko przy użyciu protokołu HTTPS",
    "Please move your setup to HTTPS" : "Przenieś konfigurację do HTTPS",
    "Access to microphone & camera was denied" : "Odmówiono dostępu do mikrofonu i kamery",
    "WebRTC is not supported in your browser" : "WebRTC nie jest obsługiwany w Twojej przeglądarce",
    "Please use a different browser like Firefox or Chrome" : "Użyj innej przeglądarki, takiej jak Firefox lub Chrome",
    "Error while accessing microphone & camera" : "Wystąpił błąd podczas dostępu do mikrofonu i kamery",
    "%s Talk on your mobile devices" : "%s Talk na urządzeniach mobilnych",
    "Join conversations at any time, anywhere, on any device." : "Dołącz do rozmów w dowolnym momencie, w dowolnym miejscu i na dowolnym urządzeniu.",
    "Android app" : "Aplikacja Android",
    "iOS app" : "Aplikacja na iOS",
    "__language_name__" : "Polski",
    "Webhook Demo" : "Demo Webhook",
    "Call summary (%s)" : "Podsumowanie połączenia (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Bot podsumowujący rozmowę publikuje po połączeniu wiadomość zawierającą listę wszystkich uczestników i opis zadań",
    "Tasks" : "Zadania",
    "Notes" : "Notatki",
    "Reports" : "Raporty",
    "Decisions" : "Decyzje",
    "Agenda" : "Porządek obrad",
    "Call summary" : "Podsumowanie rozmowy",
    "Call summary - {title}" : "Podsumowanie rozmowy - {title}",
    "Talk to %s" : "Rozmawiaj z %s",
    "Talk conversation for event" : "Rozpocznij rozmowę dotyczącą wydarzenia",
    "Client Push is installed, this improves the performance of desktop clients." : "Client Push jest zainstalowany, a to znacząco zwiększa wydajność w klienckich aplikacjach desktopowych. ",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} nie jest zainstalowane, to może prowadzić do problemów z wydjanością i prawidłowym działaniem aplikacji klienckich. ",
    "Next meeting" : "Następne spotkanie",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Zaplanuj spotkanie z kalendarza. Rozmowa w Talk musi być ustawiona jako lokalizacja, aby pojawiła się tutaj",
    "Join conversations from remote Nextcloud servers" : "Dołącz do rozmów ze zdalnych serwerów Nextcloud",
    "Your default media state has been saved" : "Twój domyślny stan multimediów został zapisany",
    "Set reminder for later today" : "Ustaw przypomnienie na dzisiaj na późniejszy czas",
    "Set reminder for tomorrow" : "Ustaw przypomnienie na jutro",
    "Set reminder for this weekend" : "Ustaw przypomnienie na ten weekend",
    "Set reminder for next week" : "Ustaw przypomnienie na przyszły tydzień",
    "Generate summary" : "Wygeneruj podsumowanie",
    "Open poll • You voted already" : "Otwórz sondę • Już głosowałeś",
    "Open poll • Click to vote" : "Otwórz sondę • Kliknij, aby głosować",
    "Poll • Ended" : "Sonda • Zakończona",
    "Talk recording from {time} ({conversation})" : "Nagranie rozmowy z {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Wyniki sondy • %n głos","Wyniki sondy • %n głosy","Wyniki sondy • %n głosów","Wyniki sondy • %n głosów"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Otwórz sondę • %n głos","Otwórz sondę • %n głosy","Otwórz sondę • %n głosów","Otwórz sondę • %n głosów"],
    "Submit vote" : "Wyślij głos",
    "Your privacy setting has been saved" : "Twoje ustawienia prywatności zostały zapisane",
    "Your personal setting has been saved" : "Twoje ustawienia osobiste zostały zapisane",
    "Failed to save sounds setting" : "Nie udało się zapisać ustawienia dźwięków",
    "Sounds setting saved" : "Zapisano ustawienia dźwięków",
    "Always shown if recording consent is required" : "Zawsze wyświetlane, jeśli wymagana jest zgoda na nagrywanie",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Usługa Nextcloud Talk została zaktualizowana. Nie można rozpocząć ani dołączyć do rozmowy.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Dołączyłeś do rozmowy w innym oknie lub urządzeniu. Ta sesja została zamknięta, ponieważ nie jest obecnie obsługiwana przez Nextcloud Talk.",
    "Nextcloud Talk was updated." : "Zaktualizowano Nextcloud Talk.",
    "Nextcloud is in maintenance mode." : "Nextcloud jest w trybie konserwacji.",
    "Nextcloud Talk Federation was updated." : "Zaktualizowano Nextcloud Talk Federation.",
    "Enable live translation" : "Włącz tłumaczenie na żywo",
    "_Open poll • %n vote • Your vote is anonymous_::_Open poll • %n votes • Your vote is anonymous_" : ["Otwarta ankieta • %n głos • Twój głos jest anonimowy","Otwarta ankieta • %n głosów • Twój głos jest anonimowy","Otwarta ankieta • %n głosów • Twój głos jest anonimowy","Otwarta ankieta • %n głosy • Twój głos jest anonimowy"],
    "Open poll • You voted already • Your vote is anonymous" : "Otwarta ankieta • Już zagłosowałeś(-aś) • Twój głos jest anonimowy",
    "Open poll • Your vote is anonymous" : "Otwarta ankieta • Twój głos jest anonimowy",
    "I picked list style" : "Wybrałem widok listy",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Hej! Korzystasz z Talk w widoku listy czy z dymkami wiadomości?"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
